/**
 *  ▄▄▄·  ▄▄▄· ▄▄▄· ▄▄▄▄▄ ▄ .▄ ▄· ▄▌
 * ▐█ ▀█ ▐█ ▄█▐█ ▀█ •██  ██▪▐█▐█▪██▌
 * ▄█▀▀█  ██▀·▄█▀▀█  ▐█.▪██▀▐█▐█▌▐█▪
 * ▐█ ▪▐▌▐█▪·•▐█ ▪▐▌ ▐█▌·██▌▐▀ ▐█▀·.
 *  ▀  ▀ .▀    ▀  ▀  ▀▀▀ ▀▀▀ ·  ▀ •
 *  <https://fortreeforums.xyz>
 */

!function($, window, document, _undefined)
{
    "use strict";
    
    XF.PostbitPreview = XF.Element.newHandler({
        /**
         * TESTER ELEMENTS
         */
        testBg:     $('#test-postbitBg'),
        testFilter: $('.ap-ss-postbitFilter'),
        testText:   $('.js-postbitTooltip dt, .js-postbitTooltip dd'),

        /**
         * OPTION ELEMENTS
         */
        disable:     $('#postbitDisable'),
        background:  $('#postbitBackground'),
        presetBg:    $('#postbitPresetSelector'),
        bgType:      $('#postbitBgType:checked'),
        bgRepeat:    $('#postbitBgRepeat input:radio'),
        bgPosition:  $('#postbitBgPositionX, #postbitBgPositionY'),
        bgPositionX: $('#postbitBgPositionX'),
        bgPositionY: $('#postbitBgPositionY'),
        bgSize:      $('#postbitBgSize input:radio'),
        filter:      $('#postbitBgOpacity, #postbitBgBrightness, #postbitBgContrast, #postbitBgBlur'),
        opacity:     $('#postbitBgOpacity'),
        brightness:  $('#postbitBgBrightness'),
        contrast:    $('#postbitBgContrast'),
        blur:        $('#postbitBgBlur'),
        textColor:   $('#postbitTextColor'),
        textShadow:  $('#postbitTextShadow'),
        css:         $('#postbitCss'),

        init: function()
        {
            var t = this;

            var gradDir = XF.config.postbitGradDir;
            var gradBtm = XF.config.postbitGradEnd;
            var gradTop = XF.config.postbitGradStart;
            var dataDir = XF.config.postbitDir;
            var userBG  = XF.config.postbitUserBG;

            this.background.on('input', function()
            {
                var bg = 'linear-gradient('+gradDir+', '+gradTop+', '+gradBtm+'), url('+$(this).val()+')';

                t.testBg.css({
                    'background-image':    bg,
                    'background-position': '50%',
                    'background-size':     'cover'
                });
            });

            this.presetBg.on('change', function()
            {
                var bgSelection = $(this).find('option:selected').val();

                t.testBg.css(
                    'background-image',
                    'linear-gradient('+gradDir+', '+gradTop+', '+gradBtm+'), url('+dataDir+'presets/'+bgSelection+')'
                );
            });

            this.bgRepeat.on('change', function()
            {
                setBackgroundRepeat(t.testBg, $(this).val());
            });

            this.bgPosition.on('change', function()
            {
                var xAxis = t.bgPositionX.val();
                var yAxis = t.bgPositionY.val();

                t.testBg.css('background-position', xAxis + '% ' + yAxis + '%');
            });

            this.bgSize.on('change', function()
            {
                switch(this.value)
                {
                    case 'auto':
                        t.testBg.css('background-size', 'auto');
                    break;
                    case 'contain':
                        t.testBg.css('background-size', 'contain');
                    break;
                    case 'cover':
                        t.testBg.css('background-size', 'cover');
                    break;
                }
            });

            this.filter.on('change', function()
            {
                var opacity    = parseInt(t.opacity.val());
                var brightness = parseFloat(t.brightness.val());
                var contrast   = parseInt(t.contrast.val());
                var blur       = parseInt(t.blur.val());

                t.testFilter.css(
                    'backdrop-filter', 'brightness('+brightness+') opacity('+opacity+'%) contrast('+contrast+'%) blur('+blur+'px)'
                );
            });

            this.textColor.on('input', function()
            {
                t.testText.css('color', $(this).val());
            });

            this.disable.on('change', function()
            {
                if($(this).prop('checked'))
                {
                    t.testBg.css('background', 'transparent');
                } 
                else 
                {
                    var urlBg    = t.background.val();
                    var presetBg = t.presetBg.find('option:selected').val();
                    var type     = t.bgType.val();

                    if(t.css.val()) // CSS
                    {
                        t.testBg.attr('style', t.css.val());
                    }
                    else if(type == 0)  // URL
                    {
                        t.testBg.css(
                            'background-image',
                            'linear-gradient('+gradDir+', '+gradTop+', '+gradBtm+'), url('+urlBg+')'
                        );
                    }
                    else if(type == 1)  // Upload
                    {
                        t.testBg.css(
                            'background-image',
                            'linear-gradient('+gradDir+', '+gradTop+', '+gradBtm+'), url('+dataDir+userBG+')'
                        );
                    }
                    else if(type == 2)  // Preset
                    {
                        t.testBg.css(
                            'background-image',
                            'linear-gradient('+gradDir+', '+gradTop+', '+gradBtm+'),url('+dataDir+'presets/'+presetBg+')'
                        );
                    }
                };
            });

            this.textShadow.on('change',function()
            {
                processCheckbox(
                    $(this),
                    t.testText,
                    'text-shadow',
                    '0.05em 0 black,0 0.05em black,-0.05em 0 black,0 -0.05em black',
                    '0px 0px'
                )
            });

            this.css.on('change',function()
            {
                t.testBg.attr('style', $(this).val());
            });
        }
    });
    
    XF.Element.register('postbit-preview', 'XF.PostbitPreview');
}
(jQuery, window, document);
