/**
 *  ▄▄▄·  ▄▄▄· ▄▄▄· ▄▄▄▄▄ ▄ .▄ ▄· ▄▌
 * ▐█ ▀█ ▐█ ▄█▐█ ▀█ •██  ██▪▐█▐█▪██▌
 * ▄█▀▀█  ██▀·▄█▀▀█  ▐█.▪██▀▐█▐█▌▐█▪
 * ▐█ ▪▐▌▐█▪·•▐█ ▪▐▌ ▐█▌·██▌▐▀ ▐█▀·.
 *  ▀  ▀ .▀    ▀  ▀  ▀▀▀ ▀▀▀ ·  ▀ •
 *  <https://fortreeforums.xyz>
 */

!function($, window, document, _undefined)
{
    "use strict";
    
    XF.TitlePreview = XF.Element.newHandler({
        /**
         * TESTER ELEMENTS
         */
        testCustomTitle:  $('#test-previewText--customTitle'),
        testFontBg:       $('.test-previewText--customTitleBg'),
        testSparkle:      $('#test-previewText--customTitleSparkle'),

        /**
         * OPTION ELEMENTS
         */
        bold:             $('#customTitleBold'),
        italic:           $('#customTitleItalic'),
        underline:        $('#customTitleUnderline'),
        colorSolid:       $('#customTitleColorSolid'),
        colorType:        $('#customTitleColorType'),
        colorGradStart:   $('#customTitleColorStart'),
        colorGradEnd:     $('#customTitleColorEnd'),
        colorOptions:     $('#customTitleColorSolid, #customTitleColorStart, #customTitleColorEnd'),
        font:             $('#customTitleFont'),
        glow:             $('#customTitleGlow'),
        glowStrength:     $('#customTitleGlowStrength'),
        glowAlt:          $('#customTitleGlowAlt'),
        glowCss:          $('#customTitleGlowCss'),
        glowOptions:      $('#customTitleGlow, #customTitleGlowAlt, #customTitleGlowCss'),
        innerTextAnim:    $('#customTitleInnerTextAnim'),
        sparkle:          $('#customTitleSparkle'),
        
        init: function()
        {
            var t = this;

            this.bold.on('change', function()
            {
                processCheckbox($(this), t.testCustomTitle, 'font-weight', 'bold', 'normal');
            });

            this.italic.on('change', function()
            {
                processCheckbox($(this), t.testCustomTitle, 'font-style', 'italic', 'normal');
            });

            this.underline.on('change', function()
            {
                processCheckbox($(this), t.testCustomTitle, 'text-decoration', 'underline', 'none');
            });

            this.colorOptions.on('input', function()
            {
                t.setColor(t.colorType.find('input:checked').val());
            });

            this.colorType.on('change', function()
            {
                t.setColor($(this).find('input:checked').val());
            });

            this.font.on('change', function()
            {
                setFont(t.testCustomTitle, $(this).find('option:selected').val());
            });

            this.glowOptions.on('input', function()
            {
                t.setGlow(t.glowStrength.find('input:checked').val());
            });

            this.glowStrength.on('change', function()
            {
                t.setGlow($(this).find(':checked').val());
            });

            this.innerTextAnim.on('input', function()
            {
                setInnerTextAnimation(t.testFontBg, $(this).val());
            });

            this.sparkle.on('change', function()
            {
                var sparkle = 'ap-sparkle-' + $(this).find('option:selected').val();

                setSparkle(t.testSparkle, sparkle);
            });
        },

        setColor: function(colorType)
        {
            setColor(
                this.testCustomTitle,
                this.testFontBg,
                this.colorSolid.val(),
                this.colorGradStart.val(),
                this.colorGradEnd.val(),
                colorType
            );
        },

        setGlow: function(glowStrength)
        {
            setGlow(
                this.testCustomTitle,
                this.glow.val(),
                this.glowAlt.val(),
                this.glowCss.val(),
                glowStrength
            );
        }
    });
    
    XF.Element.register('title-preview', 'XF.TitlePreview');
}
(jQuery, window, document);
