/**
 *  ▄▄▄·  ▄▄▄· ▄▄▄· ▄▄▄▄▄ ▄ .▄ ▄· ▄▌
 * ▐█ ▀█ ▐█ ▄█▐█ ▀█ •██  ██▪▐█▐█▪██▌
 * ▄█▀▀█  ██▀·▄█▀▀█  ▐█.▪██▀▐█▐█▌▐█▪
 * ▐█ ▪▐▌▐█▪·•▐█ ▪▐▌ ▐█▌·██▌▐▀ ▐█▀·.
 *  ▀  ▀ .▀    ▀  ▀  ▀▀▀ ▀▀▀ ·  ▀ •
 *  <https://fortreeforums.xyz>
 */

!function($, window, document, _undefined)
{
    "use strict";

    XF.UsernamePreview = XF.Element.newHandler({
        /**
         * TESTER ELEMENTS
         */
        testUsername:  $('#test-previewText--username'),
        testFontBg:    $('.test-previewText--usernameBg'),
        testSparkle:   $('#test-previewText--usernameSparkle'),
        testIconFa:    $('#test-previewIcon--fa'),
        testImgIcon:   $('#test-previewIcon--image'),

        /**
         * OPTION ELEMENTS
         */
        bold:           $('#usernameBold'),
        italic:         $('#usernameItalic'),
        underline:      $('#usernameUnderline'),
        colorSolid:     $('#usernameColorSolid'),
        colorType:      $('#usernameColorType'),
        colorGradStart: $('#usernameColorStart'),
        colorGradEnd:   $('#usernameColorEnd'),
        colorOptions:   $('#usernameColorSolid, #usernameColorStart, #usernameColorEnd'),
        font:           $('#usernameFont'),
        glow:           $('#usernameGlow'),
        glowStrength:   $('#usernameGlowStrength'),
        glowAlt:        $('#usernameGlowAlt'),
        glowCss:        $('#usernameGlowCss'),
        glowOptions:    $('#usernameGlow, #usernameGlowAlt, #usernameGlowCss'),
        innerTextAnim:  $('#usernameInnerTextAnim'),
        sparkle:        $('#usernameSparkle'),

        /**
         * ICON OPTION ELEMENTS
         */
        iconType:      $('#usernameIconType'),
        icon:          $('#usernameIconInput'),
        iconColor:     $('#usernameIconColor'),
        iconPosition:  $('#usernameIconPosition'),

        init: function()
        {
            var t = this;

            this.bold.on('change', function()
            {
                processCheckbox($(this), t.testUsername, 'font-weight', 'bold', 'normal');
            });

            this.italic.on('change', function()
            {
                processCheckbox($(this), t.testUsername, 'font-style', 'italic', 'normal');
            });

            this.underline.on('change', function()
            {
                processCheckbox($(this), t.testUsername, 'text-decoration', 'underline', 'none');
            });

            this.colorOptions.on('input', function()
            {
                t.setColor(t.colorType.find('input:checked').val());

                if(XF.config.unameIconStyling == 'inherit')
                {
                    createTextFromClip(t.testIconFa);
                }
            });

            this.colorType.on('change', function()
            {
                t.setColor($(this).find('input:checked').val());
            });

            this.font.on('change', function()
            {
                setFont(t.testUsername, $(this).find('option:selected').val());
            });

            this.glowOptions.on('input', function()
            {
                t.setGlow(t.glowStrength.find('input:checked').val());
            });

            this.glowStrength.on('change', function()
            {
                t.setGlow($(this).find(':checked').val());
            });

            this.innerTextAnim.on('input', function()
            {
                var image = $(this).val();

                setInnerTextAnimation(t.testFontBg, image);

                if(XF.config.unameIconStyling == 'inherit')
                {
                    setInnerTextAnimation(t.testIconFa, image);
                }
            });

            this.sparkle.on('change', function()
            {
                var sparkle = 'ap-sparkle-' + $(this).find('option:selected').val();

                setSparkle(t.testSparkle, sparkle);
            });

            this.iconType.on('change', function()
            {
                t.proccessIconType(parseInt($(this).find(':checked').val()));
            });

            this.icon.on('iconpickerSelected', function()
            {
                t.testIconFa.removeClass().addClass($(this).val());
            });

            this.iconPosition.on('change', function()
            {
                switch(parseInt($(this).find(':checked').val()))
                {
                    case 0:
                       t.testUsername.before(t.testIconFa);
                       t.testUsername.before(t.testImgIcon);
                    break;
                    case 1:
                       t.testUsername.after(t.testIconFa);
                       t.testUsername.after(t.testImgIcon);
                    break;
                }
            });

            this.iconColor.on('input',function()
            {
                t.testIconFa.css('color', $(this).val());
            });
        },

        proccessIconType: function(value)
        {
            switch(parseInt(value))
            {
                case 0:
                    this.testImgIcon.hide();
                    this.testIconFa.show();
                break;
                case 1:
                    this.testImgIcon.show();
                    this.testIconFa.hide();
                break;
            }
        },

        setColor: function(colorType)
        {
            setColor(
                this.testUsername,
                this.testFontBg,
                this.colorSolid.val(),
                this.colorGradStart.val(),
                this.colorGradEnd.val(),
                colorType
            );
        },

        setGlow: function(glowStrength)
        {
            setGlow(
                this.testUsername,
                this.glow.val(),
                this.glowAlt.val(),
                this.glowCss.val(),
                glowStrength
            );
        }
    });

    XF.Element.register('username-preview', 'XF.UsernamePreview');
}
(jQuery, window, document);
