/**
 *  ▄▄▄·  ▄▄▄· ▄▄▄· ▄▄▄▄▄ ▄ .▄ ▄· ▄▌
 * ▐█ ▀█ ▐█ ▄█▐█ ▀█ •██  ██▪▐█▐█▪██▌
 * ▄█▀▀█  ██▀·▄█▀▀█  ▐█.▪██▀▐█▐█▌▐█▪
 * ▐█ ▪▐▌▐█▪·•▐█ ▪▐▌ ▐█▌·██▌▐▀ ▐█▀·.
 *  ▀  ▀ .▀    ▀  ▀  ▀▀▀ ▀▀▀ ·  ▀ •
 *  <https://fortreeforums.xyz>
 */

function processCheckbox(element, testElement, property, checkedValue, value)
{
    if(element.prop('checked'))
    {
        testElement.css(property, checkedValue);
    }
    else
    {
        testElement.css(property, value);
    };
};

function setBackgroundRepeat(element, value)
{
    switch(parseInt(value))
    {
        case 0:
            element.css('background-repeat', 'no-repeat');
        break;
        case 1:
            element.css('background-repeat', 'repeat-x');
        break;
        case 2:
            element.css('background-repeat', 'repeat-y');
        break;
        case 3: // Repeat both (x + y)
            element.css('background-repeat', 'repeat');
        break;
    }
};

function setColor(element, element2, colorSolid, colorGradStart, colorGradEnd, type)
{
    switch(parseInt(type))
    {
        case 0: // Solid
            this.createTextFromClip(element, element2);

            element.css('color', colorSolid);
        break;
        case 1: // Gradient
            this.createGradient(element2, colorGradStart, colorGradEnd);
        break;
    }
};

function setGlow(element, glow, glowAlt, glowCss, strength)
{
    var weak   = '0px 0px 8px ' + glow;
    var medium = '0 0 2px '+glow+', 0 0 2px '+glow+', 0 0 4px '+glow+', 0 0 6px '+glow;

    var strong = '0 0 2px '+glow+', 0 0 4px '+glow+', 0 0 6px '+glow+', 0 0 8px '+glow+', 0 0 10px '+glow;

    switch(parseInt(strength))
    {
        case 0: // none
            element.css({
                'animation':   'none',
                'text-shadow': '0px 0px'
            });
        break;
        case 1: // weak
            element.css({
                'animation':   'none',
                'text-shadow': weak
            });
        break;
        case 2: // medium
            element.css({
                'animation':   'none',
                'text-shadow': medium
            });
        break;
        case 3: // strong
            element.css({
                'animation':   'none',
                'text-shadow': strong
            });
        break;
        case 4: // animated
            this.setAnimatedGlow(element, glow, glowAlt);
        break;
        case 5: // css
            element.css({
                'animation':   'none',
                'text-shadow': glowCss
            });
        break;
    }
};

function setAnimatedGlow(element, glow, glowAlt)
{
    $('#ap-animglow-css').remove();

    $('<style id="ap-animglow-css" type="text/css">\
        @keyframes ap-test-title-glow {\
            from {\
                text-shadow: 0 0 2px '+glow+', 0 0 4px '+glow+', 0 0 6px '+glow+', 0 0 8px '+glow+', 0 0 10px '+glow+';\
            }\
            to {\
                text-shadow: 0 0 1px '+glowAlt+', 0 0 2px '+glowAlt+', 0 0 4px '+glowAlt+', 0 0 6px '+glowAlt+', 0 0 8px '+glowAlt+', 0 0 10px '+glowAlt+', 0 0 12px '+glowAlt+';\
            }\
        }</style>').appendTo('head');

    element.css('animation', 'ap-test-title-glow 2s ease-in-out infinite alternate');
};

function setFont(element, font)
{
    element.css('font-family', font);

    if(!font)
    {
        element.prop('style').removeProperty('font-family');
    }
};

function setInnerTextAnimation(element, image)
{
    this.createClipFromText(element, image);

    if(!image)
    {
        this.createTextFromClip(element);
    }
};

function setSparkle(element, sparkle)
{
    element.removeClass(function (index, className) {
        return (className.match (/(^|\s)ap-sparkle-\S+/g) || []).join(' ');
    }).addClass(sparkle);
};

function createGradient(element, startColor, endColor)
{
    element.css({
        'background':              'linear-gradient(to right, ' + startColor + ', ' + endColor + ')',
        '-webkit-background-clip': 'text',
        'background-clip':         'text',
        '-webkit-fill-color':      'transparent',
        'text-fill-color':         'transparent'
    });
};

/** Used for creating inner-text animations */
function createClipFromText(element, image)
{
    element.css({
        'background-image':        'url(' + image + ')',
        '-webkit-background-clip': 'text',
        'background-clip':         'text',
        '-webkit-text-fill-color': 'transparent',
        'text-fill-color':         'transparent',
        'background-size':         '200% auto',
        'animation':               'tBG 7s ease-in-out infinite alternate'
    });
};

/** Used for restoring text from an inner-text animation */
function createTextFromClip(element, element2)
{
    element.css({
        'background':               'unset',
        '-webkit-background-clip':  'unset',
        'background-clip':          'unset',
        '-webkit-text-fill-color':  'unset',
        'text-fill-color':          'unset',
        'background-size':          '',
        'animation':                ''
    });

    if(element2)
    {
        element2.css({
            '-webkit-text-fill-color': 'unset',
            'text-fill-color':         'unset',
            'background':              'unset'
        });
    };
};
