<?php

/**
 *  ▄▄▄·  ▄▄▄· ▄▄▄· ▄▄▄▄▄ ▄ .▄ ▄· ▄▌
 * ▐█ ▀█ ▐█ ▄█▐█ ▀█ •██  ██▪▐█▐█▪██▌
 * ▄█▀▀█  ██▀·▄█▀▀█  ▐█.▪██▀▐█▐█▌▐█▪
 * ▐█ ▪▐▌▐█▪·•▐█ ▪▐▌ ▐█▌·██▌▐▀ ▐█▀·.
 *  ▀  ▀ .▀    ▀  ▀  ▀▀▀ ▀▀▀ ·  ▀ •
 *  <https://fortreeforums.xyz/>
 */

namespace apathy\StyleSuite\Admin\Controller;

use apathy\StyleSuite\Helper;
use XF;
use XF\Admin\Controller\AbstractController;
use XF\Mvc\Reply\Redirect;
use XF\Util\File;

class AvatarFrames extends AbstractController
{
    public function actionIndex()
    {
        if(!XF::visitor()->hasAdminPermission('apSsManageFrames'))
        {
            return $this->noPermission();
        }

        /** @var \apathy\StyleSuite\Repository\Styles $repo */
        $repo = $this->repository('apathy\StyleSuite:Styles');

        $frames = $repo->getFramesFromCache();

        if(!$frames)
        {
            $frames = $repo->findFramesOnFileSystem();
        }

        $frameDir = $this->app()->applyExternalDataUrl('apathy/StyleSuite/frames', false);

        $viewParams = [
            'frames'   => $frames,
            'frameDir' => $frameDir
        ];

        if($this->isPost())
        {
            $file  = $this->request->getFile('frame', false);

            $input = $this->filter([
                'delete'  => 'array',
                'hidden'  => 'array',
                'special' => 'array',
                'rename'  => 'array'
            ]);

            if($file)
            {
                $this->uploadFrame($file);
            }
            elseif(!$file && $input['delete'])
            {
                $this->deleteFrames($input['delete']);
            }
            else
            {
                if($input['hidden'])
                {
                    $repo->setItemAttribute(
                        $input['hidden'],  
                        'hidden',  
                        $repo->getFramesFromCache(), 
                        'apAvatarFrames'
                    );
                }

                if($input['special'])
                {
                    $repo->setItemAttribute(
                        $input['special'], 
                        'special', 
                        $repo->getFramesFromCache(), 
                        'apAvatarFrames'
                    );
                }

                if($input['rename'])
                {
                    $repo->setItemAttribute(
                        $input['rename'], 
                        'name', 
                        $repo->getFramesFromCache(), 
                        'apAvatarFrames'
                    );
                }
            }

            /** @var \XF\Repository\Style $style */
            $style = $this->repository('XF:Style');
            $style->updateAllStylesLastModifiedDate();

            return $this->redirect($this->buildLink('manage-avatar-frames'));
        }
        
        return $this->view('apathy\StyleSuite:AvatarFrames', 'ap_ss_manage_frames', $viewParams);
    }

    public function actionQuickRebuild(): Redirect
    {
        /** 
         * User frames
         * @var \apathy\StyleSuite\Repository\Styles $repo 
         */
        $repo = $this->repository('apathy\StyleSuite:Styles');
        $repo->rebuildFrameCache();

        /** 
         * Group frames
         * @var XF\Repository\UserGroup $userGroupRepo 
         */
        $userGroupRepo = $this->repository('XF:UserGroup');
        $userGroupRepo->rebuildDisplayStyleCache();

        /** @var \XF\Repository\Style $style */
        $style = $this->repository('XF:Style');
        $style->updateAllStylesLastModifiedDate();

        return $this->redirect($this->getDynamicRedirect());
    }

    protected function uploadFrame($frame)
    {
        $dir = $this->app()->config('externalDataPath');
        $dir .= '://apathy/StyleSuite/frames/' . $frame->getFileName();

        /** @var \apathy\StyleSuite\Repository\Styles $repo */
        $repo = $this->repository('apathy\StyleSuite:Styles');

        $filename = $frame->getFileName();
        $name = Helper::stripFileExtensions($filename);

        if($repo->isValidAsset($frame, 'avatar_frame'))
        {
            if(in_array($name, Helper::getDefaultFrames()))
            {
                $repo->setDefaultItemAsDeleteUndeleted(
                    $filename, $repo->getFramesFromCache(), 'apAvatarFrames', false
                );
            }
            else
            {
                File::copyFileToAbstractedPath($frame->getTempFile(), $dir);
            }
        }

        return $repo->rebuildFrameCache();
    }

    protected function deleteFrames($frames): array
    {
        $app   = $this->app();
        $dir   = $app->config('externalDataPath').'://apathy/StyleSuite/frames/';
        $files = $app->fs()->listContents($dir);

        foreach($files as $file)
        {
            $filelist[] = $file['basename'];
        }

        $result = array_intersect($filelist, $frames);

        if(!$result)
        {
            return [];
        }

        /** @var \apathy\StyleSuite\Repository\Styles $repo */
        $repo = $this->repository('apathy\StyleSuite:Styles');

        foreach($result as $file)
        {
            $name = Helper::stripFileExtensions($file);

            if(in_array($name, Helper::getDefaultFrames()))
            {
                $repo->setDefaultItemAsDeleteUndeleted(
                    $file, $repo->getFramesFromCache(), 'apAvatarFrames'
                );
            }
            else
            {
                File::deleteFromAbstractedPath($dir . $file);
            }
        }

        return $repo->rebuildFrameCache();
    }
}