<?php

/**
 *  ▄▄▄·  ▄▄▄· ▄▄▄· ▄▄▄▄▄ ▄ .▄ ▄· ▄▌
 * ▐█ ▀█ ▐█ ▄█▐█ ▀█ •██  ██▪▐█▐█▪██▌
 * ▄█▀▀█  ██▀·▄█▀▀█  ▐█.▪██▀▐█▐█▌▐█▪
 * ▐█ ▪▐▌▐█▪·•▐█ ▪▐▌ ▐█▌·██▌▐▀ ▐█▀·.
 *  ▀  ▀ .▀    ▀  ▀  ▀▀▀ ▀▀▀ ·  ▀ •
 *  <https://fortreeforums.xyz/>
 */

namespace apathy\StyleSuite\Admin\Controller;

use apathy\StyleSuite\Helper;
use XF;
use XF\Admin\Controller\AbstractController;
use XF\Mvc\Reply\Redirect;

class Fonts extends AbstractController
{
    public function actionIndex()
    {
        if(!XF::visitor()->hasAdminPermission('apSsManageFonts'))
        {
            return $this->noPermission();
        }

        /** @var \apathy\StyleSuite\Repository\Styles $repo */
        $repo = $this->repository('apathy\StyleSuite:Styles');

        $fonts = $repo->getFontsFromCache();

        if(!$fonts)
        {
            $fonts = $repo->findFontsOnFileSystem();
        }

        $viewParams = [
            'fonts' => $fonts
        ];

        if($this->isPost())
        {
            $upload = $this->request->getFile('font', false);
            $input = $this->filter([
                'delete'  => 'array',
                'rename'  => 'array'
            ]);

            if($upload)
            {
                $this->uploadFont($upload);
            }
            elseif(!$upload && $input['delete'])
            {
                $this->deleteFonts($input['delete']);
            }
            else
            {
                if($input['rename'])
                {
                    $repo->setItemAttribute(
                        $input['rename'], 
                        'name', 
                        $repo->getFontsFromCache(), 
                        'apFonts'
                    );
                }
            }

            /** @var \XF\Repository\Style $style */
            $style = $this->repository('XF:Style');
            $style->updateAllStylesLastModifiedDate();

            return $this->redirect($this->buildLink('manage-fonts'));
        }
        
        return $this->view('apathy\StyleSuite:Fonts', 'ap_ss_manage_fonts', $viewParams);
    }

    protected function uploadFont($font): array
    {
        $dir = $this->app()->config('externalDataPath') . '/fonts/apathy/StyleSuite/';
        $dir = strtr($dir, ['data' => 'styles']);

        /** @var \apathy\StyleSuite\Repository\Styles $repo */
        $repo = $this->repository('apathy\StyleSuite:Styles');

        $filename = $font->getFileName();
        $name = Helper::stripFileExtensions($filename);

        if($repo->isValidAsset($font, 'font'))
        {
            if(in_array($name, Helper::getDefaultFonts()))
            {
                $repo->setDefaultItemAsDeleteUndeleted(
                    $filename, $repo->getFontsFromCache(), 'apFonts', false
                );
            }
            else
            {
                move_uploaded_file($font->getTempFile(), $dir . $font->getFileName());
            }
        }

        return $repo->rebuildFontCache();
    }

    protected function deleteFonts($fonts): array
    {
        $dir   = $this->app()->config('externalDataPath') . '/fonts/apathy/StyleSuite/';
        $dir   = strtr($dir, ['data' => 'styles']);
        $files = glob($dir . '*.{otf,ttf,woff,woff2,OTF,TTF,WOFF,WOFF2}', GLOB_BRACE);

        foreach($files as $file)
        {
            $filelist[] = $file;
        }

        foreach($fonts as $font)
        {
            $fontlist[] = $dir . $font;
        }

        $result = array_intersect($filelist, $fontlist);

        if(!$result)
        {
            return [];
        }

        /** @var \apathy\StyleSuite\Repository\Styles $repo */
        $repo = $this->repository('apathy\StyleSuite:Styles');

        foreach($result as $file)
        {
            if(file_exists($file))
            {
                $name = Helper::stripFileExtensions($file);
                $name = str_replace($dir, '', $name);

                if(in_array($name, Helper::getDefaultFonts()))
                {
                    $repo->setDefaultItemAsDeleteUndeleted(
                        $file, $repo->getFontsFromCache(), 'apFonts'
                    );
                }
                else
                {
                    unlink($file);
                }
            }
        }

        return $repo->rebuildFontCache();
    }

    public function actionQuickRebuild(): Redirect
    {
        /** @var \apathy\StyleSuite\Repository\Styles $repo */
        $repo = $this->repository('apathy\StyleSuite:Styles');
        $repo->rebuildFontCache();

        /** @var \XF\Repository\Style $style */
        $style = $this->repository('XF:Style');
        $style->updateAllStylesLastModifiedDate();

        return $this->redirect($this->getDynamicRedirect());
    }
}
