<?php

/**
 *  ▄▄▄·  ▄▄▄· ▄▄▄· ▄▄▄▄▄ ▄ .▄ ▄· ▄▌
 * ▐█ ▀█ ▐█ ▄█▐█ ▀█ •██  ██▪▐█▐█▪██▌
 * ▄█▀▀█  ██▀·▄█▀▀█  ▐█.▪██▀▐█▐█▌▐█▪
 * ▐█ ▪▐▌▐█▪·•▐█ ▪▐▌ ▐█▌·██▌▐▀ ▐█▀·.
 *  ▀  ▀ .▀    ▀  ▀  ▀▀▀ ▀▀▀ ·  ▀ •
 *  <https://fortreeforums.xyz/>
 */

namespace apathy\StyleSuite\Admin\Controller;

use apathy\StyleSuite\Helper;
use XF;
use XF\Admin\Controller\AbstractController;
use XF\Mvc\Reply\Redirect;
use XF\Util\File;

class Postbits extends AbstractController
{
    public function actionIndex()
    {
        $visitor = XF::visitor();

        if(!$visitor->hasAdminPermission('apSsManagePostbits'))
        {
            return $this->noPermission();
        }

        /** @var \apathy\StyleSuite\Repository\Styles $repo */
        $repo = $this->repository('apathy\StyleSuite:Styles');
        $postbits = $repo->getPostbitPresetsFromCache();

        if(!$postbits)
        {
            $postbits = $repo->findPostbitPresetsOnFileSystem();
        }

        $postbitDir = $this->app()->applyExternalDataUrl('apathy/StyleSuite/postbits/presets', false);

        $viewParams = [
            'postbits'   => $postbits,
            'postbitDir' => $postbitDir
        ];

        if($this->isPost())
        {
            $file  = $this->request->getFile('postbit', false);

            $input = $this->filter([
                'delete'  => 'array',
                'hidden'  => 'array',
                'special' => 'array',
                'rename'  => 'array'
            ]);

            if($file)
            {
                $this->uploadPostbit($file);
            }
            elseif(!$file && $input['delete'])
            {
                $this->deletePostbits($input['delete']);
            }
            else
            {
                if($input['hidden'])
                {
                    $repo->setItemAttribute(
                        $input['hidden'], 
                        'hidden', 
                        $repo->getPostbitPresetsFromCache(), 
                        'apPostbitBgs'
                    );
                }

                if($input['special'])
                {
                    $repo->setItemAttribute(
                        $input['special'], 
                        'special', 
                        $repo->getPostbitPresetsFromCache(), 
                        'apPostbitBgs'
                    );
                }

                if($input['rename'])
                {
                    $repo->setItemAttribute(
                        $input['rename'], 
                        'name', 
                        $repo->getPostbitPresetsFromCache(), 
                        'apPostbitBgs'
                    );
                }
            }

            /** @var \XF\Repository\Style $style */
            $style = $this->repository('XF:Style');
            $style->updateAllStylesLastModifiedDate();

            return $this->redirect($this->buildLink('manage-postbits'));
        }
        
        return $this->view('apathy\StyleSuite:Postbits', 'ap_ss_manage_postbits', $viewParams);
    }

    protected function uploadPostbit($postbit): array
    {
        $dir = $this->app()->config('externalDataPath').'://apathy/StyleSuite/postbits/presets/'.$postbit->getFileName();

        /** @var \apathy\StyleSuite\Repository\Styles $repo */
        $repo = $this->repository('apathy\StyleSuite:Styles');

        $filename = $postbit->getFileName();
        $name = Helper::stripFileExtensions($filename);

        if($repo->isValidAsset($postbit, 'postbit_preset'))
        {
            if(in_array($name, Helper::getDefaultPostbitBgs()))
            {
                $repo->setDefaultItemAsDeleteUndeleted(
                    $filename, $repo->getPostbitPresetsFromCache(), 'apPostbitBgs', false
                );
            }
            else
            {
                File::copyFileToAbstractedPath($postbit->getTempFile(), $dir);
            }
        }

        return $repo->rebuildPostbitPresetCache();
    }

    protected function deletePostbits($postbits): array
    {
        $app   = $this->app();
        $dir   = $app->config('externalDataPath').'://apathy/StyleSuite/postbits/presets/';
        $files = $app->fs()->listContents($dir);

        foreach($files as $file)
        {
            $filelist[] = $file['basename'];
        }

        $result = array_intersect($filelist, $postbits);

        if(!$result)
        {
            return [];
        }

        /** @var \apathy\StyleSuite\Repository\Styles $repo */
        $repo = $this->repository('apathy\StyleSuite:Styles');

        foreach($result as $file)
        {
            $name = Helper::stripFileExtensions($file);

            if(in_array($name, Helper::getDefaultPostbitBgs()))
            {
                $repo->setDefaultItemAsDeleteUndeleted(
                    $file, $repo->getPostbitPresetsFromCache(), 'apPostbitBgs'
                );
            }
            else
            {
                File::deleteFromAbstractedPath($dir . $file);
            }
        }

        return $repo->rebuildPostbitPresetCache();
    }

    public function actionQuickRebuild(): Redirect
    {
        /** @var \apathy\StyleSuite\Repository\Styles $repo */
        $repo = $this->repository('apathy\StyleSuite:Styles');
        $repo->rebuildPostbitPresetCache();

        /** @var \XF\Repository\Style $style */
        $style = $this->repository('XF:Style');
        $style->updateAllStylesLastModifiedDate();

        return $this->redirect($this->getDynamicRedirect());
    }
}
