<?php

/**
 *  ▄▄▄·  ▄▄▄· ▄▄▄· ▄▄▄▄▄ ▄ .▄ ▄· ▄▌
 * ▐█ ▀█ ▐█ ▄█▐█ ▀█ •██  ██▪▐█▐█▪██▌
 * ▄█▀▀█  ██▀·▄█▀▀█  ▐█.▪██▀▐█▐█▌▐█▪
 * ▐█ ▪▐▌▐█▪·•▐█ ▪▐▌ ▐█▌·██▌▐▀ ▐█▀·.
 *  ▀  ▀ .▀    ▀  ▀  ▀▀▀ ▀▀▀ ·  ▀ •
 *  <https://fortreeforums.xyz/>
 */

namespace apathy\StyleSuite\Admin\Controller;

use apathy\StyleSuite\Helper;
use XF;
use XF\Admin\Controller\AbstractController;
use XF\Mvc\Reply\Redirect;
use XF\Util\File;

class Sparkles extends AbstractController
{
    public function actionIndex()
    {
        $visitor = XF::visitor();

        if(!$visitor->hasAdminPermission('apSsManageSparkles'))
        {
            return $this->noPermission();
        }

        /** @var \apathy\StyleSuite\Repository\Styles $repo */
        $repo = $this->repository('apathy\StyleSuite:Styles');

        $sparkles = $repo->getSparklesFromCache();

        if(!$sparkles)
        {
            $sparkles = $repo->findSparklesOnFileSystem();
        }

        $sparkleDir = $this->app()->applyExternalDataUrl('apathy/StyleSuite/sparkles', false);

        $viewParams = [
            'sparkles'   => $sparkles,
            'sparkleDir' => $sparkleDir
        ];

        if($this->isPost())
        {
            $upload = $this->request->getFile('sparkle', false);

            $input  = $this->filter([
                'delete'  => 'array',
                'rename'  => 'array'
            ]);

            if($upload)
            {
                $this->uploadSparkle($upload);
            }
            elseif(!$upload && $input['delete'])
            {
                $this->deleteSparkles($input['delete']);
            }
            else
            {
                if($input['rename'])
                {
                    $repo->setItemAttribute(
                        $input['rename'], 
                        'name',
                        $repo->getSparklesFromCache(), 
                        'apSparkles'
                    );
                }
            }

            /** @var \XF\Repository\Style $style */
            $style = $this->repository('XF:Style');
            $style->updateAllStylesLastModifiedDate();

            return $this->redirect($this->buildLink('manage-sparkles'));
        }
        
        return $this->view('apathy\StyleSuite:Sparkles', 'ap_ss_manage_sparkles', $viewParams);
    }

    protected function uploadSparkle($sparkle): array
    {
        $app = $this->app();
        $dir = $app->config('externalDataPath').'://apathy/StyleSuite/sparkles/'.$sparkle->getFileName();

        /** @var \apathy\StyleSuite\Repository\Styles $repo */
        $repo = $this->repository('apathy\StyleSuite:Styles');

        $filename = $sparkle->getFileName();
        $name = Helper::stripFileExtensions($filename);

        if($repo->isValidAsset($sparkle, 'sparkle'))
        {
            if(in_array($name, Helper::getDefaultSparkles()))
            {
                $repo->setDefaultItemAsDeleteUndeleted(
                    $filename, $repo->getSparklesFromCache(), 'apSparkles', false
                );
            }
            else
            {
                File::copyFileToAbstractedPath($sparkle->getTempFile(), $dir);
            }
        }

        return $repo->rebuildSparkleCache();
    }

    protected function deleteSparkles($sparkles): array
    {
        $app   = $this->app();
        $dir   = $app->config('externalDataPath').'://apathy/StyleSuite/sparkles/';
        $files = $app->fs()->listContents($dir);

        foreach($files as $file)
        {
            $filelist[] = $file['basename'];
        }

        $result = array_intersect($filelist, $sparkles);

        if(!$result)
        {
            return [];
        }

        /** @var \apathy\StyleSuite\Repository\Styles $repo */
        $repo = $this->repository('apathy\StyleSuite:Styles');

        foreach($result as $file)
        {
            $name = Helper::stripFileExtensions($file);

            if(in_array($name, Helper::getDefaultSparkles()))
            {
                $repo->setDefaultItemAsDeleteUndeleted(
                    $file, $repo->getSparklesFromCache(), 'apSparkles'
                );
            }
            else
            {
                File::deleteFromAbstractedPath($dir . $file);
            }
        }
        
        return $repo->rebuildSparkleCache();
    }

    public function actionQuickRebuild(): Redirect
    {
        /** @var \apathy\StyleSuite\Repository\Styles $repo */
        $repo = $this->repository('apathy\StyleSuite:Styles');
        $repo->rebuildSparkleCache();

        /** @var \XF\Repository\Style $style */
        $style = $this->repository('XF:Style');
        $style->updateAllStylesLastModifiedDate();

        return $this->redirect($this->getDynamicRedirect());
    }
}
