<?php

/**
 *  ▄▄▄·  ▄▄▄· ▄▄▄· ▄▄▄▄▄ ▄ .▄ ▄· ▄▌
 * ▐█ ▀█ ▐█ ▄█▐█ ▀█ •██  ██▪▐█▐█▪██▌
 * ▄█▀▀█  ██▀·▄█▀▀█  ▐█.▪██▀▐█▐█▌▐█▪
 * ▐█ ▪▐▌▐█▪·•▐█ ▪▐▌ ▐█▌·██▌▐▀ ▐█▀·.
 *  ▀  ▀ .▀    ▀  ▀  ▀▀▀ ▀▀▀ ·  ▀ •
 *  <https://fortreeforums.xyz/>
 */

namespace apathy\StyleSuite\Admin\Controller\Style;

use apathy\StyleSuite\Helper;
use XF;
use XF\Entity\User;
use XF\Mvc\ParameterBag;

trait CustomTitle 
{
    public function actionCustomTitleStyle(ParameterBag $params)
    {
        if(XF::options()->ap_disable_title_styles
        || !XF::visitor()->hasPermission('ap_styles', 'ap_change_ttl_style_ad'))
        {
            return $this->noPermission();
        }

        $this->assertAdminPermission('user');

        $user = $this->assertViewableUser($params['user_id']);

        /** @var \apathy\StyleSuite\Repository\Styles $repo */
        $repo = $this->repository('apathy\StyleSuite:Styles');

        $fontCache = Helper::cleanUpFontNames($repo->getFontsFromCache());
        $sparkleCache = $repo->getSparklesFromCache();

        if($this->isPost())
        {
            $this->customTitleStyleSaveProcess($user)->run();

            return $this->redirect($this->getDynamicRedirect());
        }

        $viewParams = [
            'fontCache'    => $fontCache,
            'sparkleCache' => $sparkleCache,
            'user'         => $user
        ];

        return $this->view('apathy\StyleSuite:UserStyle', 'ap_ss_user_edit_custom_title', $viewParams);
    }

    protected function customTitleStyleSaveProcess(User $user)
    {
        $this->assertAdminPermission('user');
        $this->isValidAdminPassword($user);

        $form = $this->formAction();

        $input = $this->filter([
            'ttl_bold'        => 'bool',
            'ttl_color'       => 'str',
            'ttl_color_type'  => 'int',
            'ttl_color_start' => 'str',
            'ttl_color_end'   => 'str',
            'ttl_font'        => 'str',
            'ttl_glow'        => 'str',
            'ttl_glow_alt'    => 'str',
            'ttl_glow_str'    => 'int',
            'ttl_glow_css'    => 'str',
            'ttl_italic'      => 'bool',
            'ttl_sparkle'     => 'str',
            'ttl_underline'   => 'bool',
            'ttl_bg'          => 'str'
        ]);

        $colors = [
            $input['ttl_color'],
            $input['ttl_color_start'],
            $input['ttl_color_end'],
            $input['ttl_glow'],
            $input['ttl_glow_alt']
        ];

        if(!empty($colors))
        {
            Helper::verifyColors($colors);
        }

        if($input['ttl_glow_css'])
        {
            Helper::verifyCss($input['ttl_glow_css']);
        }

        $form->basicEntitySave($user, ['ap_title_style' => $input]);

        return $form;
    }
} 
