<?php

/**
 *  ▄▄▄·  ▄▄▄· ▄▄▄· ▄▄▄▄▄ ▄ .▄ ▄· ▄▌
 * ▐█ ▀█ ▐█ ▄█▐█ ▀█ •██  ██▪▐█▐█▪██▌
 * ▄█▀▀█  ██▀·▄█▀▀█  ▐█.▪██▀▐█▐█▌▐█▪
 * ▐█ ▪▐▌▐█▪·•▐█ ▪▐▌ ▐█▌·██▌▐▀ ▐█▀·.
 *  ▀  ▀ .▀    ▀  ▀  ▀▀▀ ▀▀▀ ·  ▀ •
 *  <https://fortreeforums.xyz/>
 */

namespace apathy\StyleSuite\Admin\Controller\Style;

use apathy\StyleSuite\Helper;
use XF;
use XF\Entity\User;
use XF\Mvc\ParameterBag;

trait Post  
{
    public function actionPostStyle(ParameterBag $params)
    {
        if(XF::options()->ap_disable_post_styles
        || !XF::visitor()->hasPermission('ap_styles', 'ap_change_post_style_ad'))
        {
            return $this->noPermission();
        }

        $this->assertAdminPermission('user');

        $user = $this->assertViewableUser($params['user_id']);

        /** @var \apathy\StyleSuite\Repository\Styles $repo */
        $repo = $this->repository('apathy\StyleSuite:Styles');

        $fontCache = Helper::cleanUpFontNames($repo->getFontsFromCache());

        if($this->isPost())
        {
            $this->postStyleSaveProcess($user)->run();

            return $this->redirect($this->getDynamicRedirect());
        }

        $viewParams = [
            'fontCache'    => $fontCache,
            'user'         => $user
        ];

        return $this->view('apathy\StyleSuite:UserStyle', 'ap_ss_user_edit_post', $viewParams);
    }

    protected function postStyleSaveProcess(User $user)
    {
        $this->assertAdminPermission('user');
        $this->isValidAdminPassword($user);
        
        $form = $this->formAction();

        $input = $this->filter([
            'post_disable'   => 'bool',
            'post_bold'      => 'bool',
            'post_italic'    => 'bool',
            'post_underline' => 'bool',
            'post_color'     => 'str',
            'post_font'      => 'str',
            'post_font_size' => 'int',
            'default_bbcode' => 'str'
        ]);

        if(!empty($post['post_color']))
        {
            Helper::verifyColors([$post['post_color']]);
        }

        $form->basicEntitySave($user, ['ap_post_style' => $input]);

        return $form;
    }
}
