<?php

/**
 *  ▄▄▄·  ▄▄▄· ▄▄▄· ▄▄▄▄▄ ▄ .▄ ▄· ▄▌
 * ▐█ ▀█ ▐█ ▄█▐█ ▀█ •██  ██▪▐█▐█▪██▌
 * ▄█▀▀█  ██▀·▄█▀▀█  ▐█.▪██▀▐█▐█▌▐█▪
 * ▐█ ▪▐▌▐█▪·•▐█ ▪▐▌ ▐█▌·██▌▐▀ ▐█▀·.
 *  ▀  ▀ .▀    ▀  ▀  ▀▀▀ ▀▀▀ ·  ▀ •
 *  <https://fortreeforums.xyz/>
 */

namespace apathy\StyleSuite\Admin\Controller\Style;

use apathy\StyleSuite\Helper;
use XF;
use XF\Entity\User;
use XF\Mvc\ParameterBag;

trait Postbit 
{
    public function actionPostbitStyle(ParameterBag $params)
    {
        if(XF::options()->ap_disable_postbit_styles
        || !XF::visitor()->hasPermission('ap_styles', 'ap_change_pb_style_ad'))
        {
            return $this->noPermission();
        }

        $this->assertAdminPermission('user');

        $user = $this->assertViewableUser($params['user_id']);

        /** @var \apathy\StyleSuite\Repository\Styles $repo */
        $repo = $this->repository('apathy\StyleSuite:Styles');

        $postbitCache = $repo->getPostbitPresetsFromCache();

        if($this->isPost())
        {
            $this->postbitStyleSaveProcess($user)->run();

            return $this->redirect($this->getDynamicRedirect());
        }

        $viewParams = [
            'postbitCache' => $postbitCache,
            'user'         => $user
        ];

        return $this->view('apathy\StyleSuite:UserStyle', 'ap_ss_user_edit_postbit', $viewParams);
    }

    protected function postbitStyleSaveProcess(User $user)
    {
        $this->assertAdminPermission('user');
        $this->isValidAdminPassword($user);
        
        $app = $this->app();
        $form = $this->formAction();

        /** @var \apathy\StyleSuite\Repository\Styles $repo */
        $repo = $this->repository('apathy\StyleSuite:Styles');

        $input = $this->filter([
            'disable'       => 'bool',
            'background'    => 'str',
            'bg_type'       => 'uint',
            'bg_repeat'     => 'str',
            'bg_position'   => 'array',
            'bg_size'       => 'str',
            'bg_opacity'    => 'uint',
            'bg_brightness' => 'float',
            'bg_contrast'   => 'uint',
            'bg_blur'       => 'uint',
            'color'         => 'str',
            'text_shadow'   => 'bool',
            'css'           => 'str'
        ]);

        if(!empty($input['bg_position']))
        {
            $input['bg_position'] = implode(',', $input['bg_position']);
        }

        $entity = $app->em()->findOne('apathy\StyleSuite:Postbit', [
            'user_id' => $user->user_id
        ]);

        if(!$entity)
        {
            $input['user_id'] = $user->user_id;

            $entity = $app->em()->create('apathy\StyleSuite:Postbit');
        }

        switch($input['bg_type'])
        {
            /** Image URL */
            case 0:
                if(Helper::verifyUrl($input['background'])
                && strpos(XF::options()->boardUrl, $input['background']) === false)
                {
                    Helper::proxyImage($input['background']);
                }
            break;
            /** Upload */
            case 1:
                /** @var \apathy\StyleSuite\Service\User\Postbit $service */
                $service = $this->service('apathy\StyleSuite:User\Postbit', $user, $entity);

                $upload = $this->request->getFile('pbit_bg_upload', false);
                
                $input['background'] = $repo->uploadPostbitImage($service, $entity, $upload);
            break;
            /** Preset */
            case 2:
                $input['background'] = $this->filter('pbit_bg_preset', 'str');
            break;
        }

        if(!empty($input['color']))
        {
            Helper::verifyColors([$input['color']]);
        }

        if(!empty($input['css']))
        {
            Helper::verifyCss($input['css']);
        }

        $form->basicEntitySave($entity, $input);

        return $form;
    }
}
