<?php

/**
 *  ▄▄▄·  ▄▄▄· ▄▄▄· ▄▄▄▄▄ ▄ .▄ ▄· ▄▌
 * ▐█ ▀█ ▐█ ▄█▐█ ▀█ •██  ██▪▐█▐█▪██▌
 * ▄█▀▀█  ██▀·▄█▀▀█  ▐█.▪██▀▐█▐█▌▐█▪
 * ▐█ ▪▐▌▐█▪·•▐█ ▪▐▌ ▐█▌·██▌▐▀ ▐█▀·.
 *  ▀  ▀ .▀    ▀  ▀  ▀▀▀ ▀▀▀ ·  ▀ •
 *  <https://fortreeforums.xyz/>
 */

namespace apathy\StyleSuite\Admin\Controller\Style;

use apathy\StyleSuite\Helper;
use XF;
use XF\Entity\User;
use XF\Mvc\ParameterBag;

trait Profile 
{
    public function actionProfileStyle(ParameterBag $params)
    {
        if(XF::options()->ap_disable_profile_styles
        || !XF::visitor()->hasPermission('ap_styles', 'ap_change_pr_style_ad'))
        {
            return $this->noPermission();
        }

        $this->assertAdminPermission('user');

        $user = $this->assertViewableUser($params['user_id']);

        if($this->isPost())
        {
            $this->profileStyleSaveProcess($user)->run();

            return $this->redirect($this->getDynamicRedirect());
        }

        $viewParams = [
            'user' => $user
        ];

        return $this->view('apathy\StyleSuite:UserStyle', 'ap_ss_user_edit_profile', $viewParams);
    }

    protected function profileStyleSaveProcess(User $user)
    {
        $this->assertAdminPermission('user');
        $this->isValidAdminPassword($user);
        
        $app = $this->app();
        $form = $this->formAction();

        $input = $this->filter([
            'pr_page_header'      => 'str',
            'pr_navbar_bg'        => 'str',
            'pr_page_bg'          => 'str',
            'pr_page_bg_type'     => 'int',
            'pr_page_bg_rep'      => 'int',
            'pr_font_color'       => 'str',
            'pr_url_color'        => 'str',
            'pr_highlight_color'  => 'str',
            'pr_box_header'       => 'str',
            'pr_box_bg'           => 'str',
            'pr_border_color'     => 'str',
            'pr_border_alt_color' => 'str',
            'pr_button'           => 'str',
            'pr_scrollbar_color'  => 'str',
            'pr_scrollbar_width'  => 'int',
            'pr_scrollbar_bg'     => 'str',
            'pr_scrollbar_radius' => 'int',
            'pr_css'              => 'str'
        ]);

        if($input['pr_page_header'])
        {
            Helper::verifyUrl($input['pr_page_header']);
        }

        $colors = [
            $input['pr_navbar_bg'],
            $input['pr_font_color'],
            $input['pr_url_color'],
            $input['pr_highlight_color'],
            $input['pr_box_header'],
            $input['pr_box_bg'],
            $input['pr_border_color'],
            $input['pr_border_alt_color'],
            $input['pr_button'],
            $input['pr_scrollbar_color'],
            $input['pr_scrollbar_bg']
        ];

        /** Solid color */
        if($input['pr_page_bg_type'] == 0)
        {
            $colors[] = $input['pr_page_bg'];
        }
        /** Image URL */
        else
        {
            Helper::verifyUrl($input['pr_page_bg']);
        }

        if(!empty($colors))
        {
            Helper::verifyColors($colors);
        }

        if($input['pr_css'])
        {
            Helper::verifyCss($input['pr_css']);
        }

        $entity = $app->em()->findOne('apathy\StyleSuite:Profile', [
            'user_id' => $user->user_id
        ]);

        if(!$entity)
        {
            $input['user_id'] = $user->user_id;

            $entity = $app->em()->create('apathy\StyleSuite:Profile');
        }

        $form->basicEntitySave($entity, $input);

        return $form;
    }
}
