<?php

/**
 *  ▄▄▄·  ▄▄▄· ▄▄▄· ▄▄▄▄▄ ▄ .▄ ▄· ▄▌
 * ▐█ ▀█ ▐█ ▄█▐█ ▀█ •██  ██▪▐█▐█▪██▌
 * ▄█▀▀█  ██▀·▄█▀▀█  ▐█.▪██▀▐█▐█▌▐█▪
 * ▐█ ▪▐▌▐█▪·•▐█ ▪▐▌ ▐█▌·██▌▐▀ ▐█▀·.
 *  ▀  ▀ .▀    ▀  ▀  ▀▀▀ ▀▀▀ ·  ▀ •
 *  <https://fortreeforums.xyz/>
 */

namespace apathy\StyleSuite\Admin\Controller\Style;

use apathy\StyleSuite\Helper;
use XF;
use XF\Entity\User;
use XF\Mvc\ParameterBag;

trait Tooltip 
{
    public function actionTooltipStyle(ParameterBag $params)
    {
        if(XF::options()->ap_disable_tooltip_styles
        || !XF::visitor()->hasPermission('ap_styles', 'ap_change_ttip_style_ad'))
        {
            return $this->noPermission();
        }

        $this->assertAdminPermission('user');

        $user = $this->assertViewableUser($params['user_id']);

        if($this->isPost())
        {
            $this->tooltipStyleSaveProcess($user)->run();

            return $this->redirect($this->getDynamicRedirect());
        }

        $viewParams = [
            'user' => $user
        ];

        return $this->view('apathy\StyleSuite:UserStyle', 'ap_ss_user_edit_tooltip', $viewParams);
    }
    
    protected function tooltipStyleSaveProcess(User $user)
    {
        $this->assertAdminPermission('user');
        $this->isValidAdminPassword($user);
        
        $form = $this->formAction();

        $input = $this->filter([
            'ttip_font_color' => 'str',
            'ttip_url_color'  => 'str',
            'ttip_hlight'     => 'str',
            'ttip_box_bg'     => 'str',
            'ttip_border'     => 'str',
            'ttip_button'     => 'str'
        ]);

        if(!empty($ttip))
        {
            Helper::verifyColors($ttip);
        }

        $form->basicEntitySave($user, ['ap_tooltip_style' => $input]);

        return $form;
    }
}
