<?php

/**
 *  ▄▄▄·  ▄▄▄· ▄▄▄· ▄▄▄▄▄ ▄ .▄ ▄· ▄▌
 * ▐█ ▀█ ▐█ ▄█▐█ ▀█ •██  ██▪▐█▐█▪██▌
 * ▄█▀▀█  ██▀·▄█▀▀█  ▐█.▪██▀▐█▐█▌▐█▪
 * ▐█ ▪▐▌▐█▪·•▐█ ▪▐▌ ▐█▌·██▌▐▀ ▐█▀·.
 *  ▀  ▀ .▀    ▀  ▀  ▀▀▀ ▀▀▀ ·  ▀ •
 *  <https://fortreeforums.xyz/>
 */

namespace apathy\StyleSuite\Admin\Controller\Style;

use apathy\StyleSuite\Helper;
use XF;
use XF\Entity\User;
use XF\Mvc\ParameterBag;

trait Username 
{
    public function actionUsernameStyle(ParameterBag $params)
    {
        if(XF::options()->ap_disable_uname_styles
        || !XF::visitor()->hasPermission('ap_styles', 'ap_change_un_style_ad'))
        {
            return $this->noPermission();
        }

        $this->assertAdminPermission('user');

        $user = $this->assertViewableUser($params['user_id']);

        /** @var \apathy\StyleSuite\Repository\Styles $repo */
        $repo = $this->repository('apathy\StyleSuite:Styles');

        $fontCache = Helper::cleanUpFontNames($repo->getFontsFromCache());
        $sparkleCache = $repo->getSparklesFromCache();

        if($this->isPost())
        {
            $this->usernameStyleSaveProcess($user)->run();

            return $this->redirect($this->getDynamicRedirect());
        }

        $viewParams = [
            'fontCache'    => $fontCache,
            'sparkleCache' => $sparkleCache,
            'user'         => $user
        ];

        return $this->view('apathy\StyleSuite:UserStyle', 'ap_ss_user_edit_username', $viewParams);
    }

    protected function usernameStyleSaveProcess(User $user)
    {
        $this->assertAdminPermission('user');
        $this->isValidAdminPassword($user);
        
        $app = $this->app();
        $form = $this->formAction();

        /** @var \apathy\StyleSuite\Repository\Styles $repo */
        $repo = $this->repository('apathy\StyleSuite:Styles');
        
        $input = $this->filter([
            'bold'                 => 'bool',
            'italic'               => 'bool',
            'underline'            => 'bool',
            'color'                => 'str',
            'color_type'           => 'uint',
            'color_alt'            => 'str',
            'font'                 => 'str',
            'glow'                 => 'str',
            'glow_alt'             => 'str',
            'glow_strength'        => 'uint',
            'glow_css'             => 'str',
            'sparkle'              => 'str',
            'inner_text_animation' => 'str',
            'icon'                 => 'str',
            'icon_type'            => 'uint',
            'icon_color'           => 'str',
            'icon_position'        => 'bool'
        ]);

        $colors = [
            $input['color'],
            $input['color_alt'],
            $input['glow'],
            $input['glow_alt'],
            $input['icon_color']
        ];

        if(!empty($colors))
        {
            Helper::verifyColors($colors);
        }

        if(!empty($input['glow_css']))
        {
            Helper::verifyCss($input['glow_css']);
        }

        $entity = $app->em()->findOne('apathy\StyleSuite:Username', [
            'user_id' => $user->user_id
        ]);

        if(!$entity)
        {
            $input['user_id'] = $user->user_id;

            $entity = $app->em()->create('apathy\StyleSuite:Username');
        }

        /** Uploaded username icons */
        if($input['icon_type'] == 1)
        {
            /** @var \apathy\StyleSuite\Service\User\UsernameIcon $service */
            $service = $this->service('apathy\StyleSuite:User\UsernameIcon', $user, $entity);

            $upload = $this->request->getFile('icon_upload', false);
                            
            $input['icon'] = $repo->uploadUsernameIconImage($service, $entity, $upload);
        }

        $form->basicEntitySave($entity, $input);

        return $form;
    }
}
