<?php

/**
 *  ▄▄▄·  ▄▄▄· ▄▄▄· ▄▄▄▄▄ ▄ .▄ ▄· ▄▌
 * ▐█ ▀█ ▐█ ▄█▐█ ▀█ •██  ██▪▐█▐█▪██▌
 * ▄█▀▀█  ██▀·▄█▀▀█  ▐█.▪██▀▐█▐█▌▐█▪
 * ▐█ ▪▐▌▐█▪·•▐█ ▪▐▌ ▐█▌·██▌▐▀ ▐█▀·.
 *  ▀  ▀ .▀    ▀  ▀  ▀▀▀ ▀▀▀ ·  ▀ •
 *  <https://fortreeforums.xyz/>
 */

namespace apathy\StyleSuite\Block;

use XF;
use XF\App;
use XF\Mvc\Entity\Finder;
use XF\Mvc\Entity\Repository;

abstract class AbstractBlock
{
    protected $app;

    protected $options = [
        'type'     => '',
        'autolink' => false
    ];

    public function __construct(App $app)
    {
        $this->app = $app;

        $this->options = $this->getOptions();
        $this->type = $this->options['type'];
    }

    abstract public function getFontAwesomeIcon();

    abstract public function getOptionPhrase();

    public function getCssClassName(): string
    {
        $type = XF\Util\Php::camelCase($this->type);

        return 'ap-ss-profileBlock--' . $type;
    }

    public function getOptionExplainPhrase()
    {
        return '';
    }

    public function getOptions(): array
    {
        return $this->options;
    }

    public function getParams(): array
    {
        return [
            'is_enabled'            => $this->isEnabled(),
            'option_phrase'         => $this->getOptionPhrase(),
            'option_explain_phrase' => $this->getOptionExplainPhrase(),
            'fa_icon'               => $this->getFontAwesomeIcon(),
            'css_class_name'        => $this->getCssClassName(),
            'edit_template'         => $this->getEditTemplate(),
            'view_template'         => $this->getViewTemplate()
        ];
    }

    public function getType(): string
    {
        return $this->type;
    }

    public function getEditTemplate(): string
    {
        return 'ap_ss_' . $this->type . '_block_edit';
    }

    public function getViewTemplate(): string
    {
        return 'ap_ss_' . $this->type . '_block';
    }

    public function getVerificationRegex()
    {
        return '';
    }

    public function isEnabled(): bool
    {
        return true;
    }

    public function renderTemplate($template): string
    {
        return $this->app()->templater()->renderTemplate('public:' . $template, []);
    }

    protected function repository(string $id): Repository
    {
        return $this->app()->repository($id);
    }

    protected function finder(string $id): Finder
    {
        return $this->app()->finder($id);
    }

    protected function app(): App
    {
        return $this->app;
    }
}
