<?php

/**
 *  ▄▄▄·  ▄▄▄· ▄▄▄· ▄▄▄▄▄ ▄ .▄ ▄· ▄▌
 * ▐█ ▀█ ▐█ ▄█▐█ ▀█ •██  ██▪▐█▐█▪██▌
 * ▄█▀▀█  ██▀·▄█▀▀█  ▐█.▪██▀▐█▐█▌▐█▪
 * ▐█ ▪▐▌▐█▪·•▐█ ▪▐▌ ▐█▌·██▌▐▀ ▐█▀·.
 *  ▀  ▀ .▀    ▀  ▀  ▀▀▀ ▀▀▀ ·  ▀ •
 *  <https://fortreeforums.xyz/>
 */

namespace apathy\StyleSuite\Entity;

use apathy\StyleSuite\Block\AbstractBlock;
use XF;
use XF\Mvc\Entity\Entity;
use XF\Mvc\Entity\Structure;

/**
 * COLUMNS
 * @property int    $block_id
 * @property int    $user_id
 * @property string $title
 * @property string $type
 * @property string $fa_icon
 * @property string $content
 * @property int    $position
 * @property bool   $active
 */

class Block extends Entity
{
    public function hasAutolinkProperty(): bool
    {
        $block = $this->getHandler()->getOptions();

        return $block['autolink'];
    }

    public function isValidId(string $id): bool
    {
        $regex = $this->getHandler()->getVerificationRegex();

        if($regex === '')
        {
            return true;
        }

        $id = trim($id);

        if(preg_match($regex, $id))
        {
            return true;
        }

        return false;
    }

    public function getFontAwesomeIcon(): string
    {
        return $this->getHandler()->getFontAwesomeIcon();
    }

    public function getParams(): array
    {
        if(!$this->isActive())
        {
            return [];
        }

        return $this->getHandler()->getParams();
    }

    public function isEnabled(): bool
    {
        if(!$this->getHandler() || !$this->isActive())
        {
            return false;
        }

        return true;
    }

    protected function isActive(): bool
    {
        if(!$this->getHandler() || !$this->active
        || !$this->getHandler()->isEnabled())
        {
            return false;
        }

        return true;
    }

    protected function getHandler(): AbstractBlock
    {
        /** @var \apathy\StyleSuite\Repository\Block $repo */
        $repo = $this->repository('apathy\StyleSuite:Block');

        return $repo->getHandler($this->type);
    }

    public static function getStructure(Structure $structure)
    {
        $structure->table = 'xf_ap_profile_block';
        $structure->shortName = 'apathy\StyleSuite:Block';
        $structure->primaryKey = 'block_id';
        $structure->columns = [
            'block_id'     => ['type' => self::UINT, 'autoIncrement' => true],
            'user_id'      => ['type' => self::UINT,                          'default' => XF::visitor()->user_id],
            'title'        => ['type' => self::STR,  'maxLength'     => 40,   'default' => false, 'required' => true],
            'type'         => ['type' => self::STR,  'maxLength'     => 20,   'default' => false],
            'fa_icon'      => ['type' => self::STR,  'maxLength'     => 30,   'default' => false],
            'content'      => ['type' => self::STR,  'maxLength'     => 500,  'default' => false],
            'position'     => ['type' => self::UINT,                          'default' => 0],
            'active'       => ['type' => self::BOOL,                          'default' => 1]
        ];
        $structure->getters = [];
        $structure->relations = [];

        return $structure;
    }
}
