<?php

/**
 *  ▄▄▄·  ▄▄▄· ▄▄▄· ▄▄▄▄▄ ▄ .▄ ▄· ▄▌
 * ▐█ ▀█ ▐█ ▄█▐█ ▀█ •██  ██▪▐█▐█▪██▌
 * ▄█▀▀█  ██▀·▄█▀▀█  ▐█.▪██▀▐█▐█▌▐█▪
 * ▐█ ▪▐▌▐█▪·•▐█ ▪▐▌ ▐█▌·██▌▐▀ ▐█▀·.
 *  ▀  ▀ .▀    ▀  ▀  ▀▀▀ ▀▀▀ ·  ▀ •
 *  <https://fortreeforums.xyz/>
 */

namespace apathy\StyleSuite\Entity;

use XF;
use XF\Mvc\Entity\Entity;
use XF\Mvc\Entity\Structure;

/**
 * COLUMNS
 * @property int    $style_id
 * @property int    $user_id
 * @property bool   $disable
 * @property string $background
 * @property int    $bg_type
 * @property string $bg_repeat
 * @property string $bg_position
 * @property string $bg_size
 * @property int    $bg_opacity
 * @property float  $bg_brightness
 * @property int    $bg_contrast
 * @property int    $bg_blur
 * @property string $color
 * @property bool   $text_shadow
 * @property array  $css
 */

class Postbit extends Entity
{
	public function getAbstractedPostbitPath($size)
	{
		$userId = $this->user_id;

		return sprintf('data://apathy/StyleSuite/postbits/%s/%d/%d.jpg',
			$size,
			floor($userId / 1000),
			$userId
		);
	}

	public function getPostbitUrl($sizeCode, $canonical = false)
	{
		$app = $this->app();
        $options = $app->options();

		$sizeMap = [
            'l' => $options->apSsMaxPostbitWidth,
            'm' => round( $options->apSsMaxPostbitWidth / 1.5 )
        ];

		if(!isset($sizeMap[$sizeCode]))
		{
			$sizeCode = 'l';
		}

		if($this->bg_date)
		{
			$group = floor($this->user_id / 1000);

			return $app->applyExternalDataUrl(
				"apathy/StyleSuite/postbits/{$sizeCode}/{$group}/{$this->user_id}.jpg?{$this->bg_date}",
				$canonical
			);
		}

		return null;
	}

    public function getPostbitBgPosition(): array
    {
        if(empty($this->bg_position))
        {
            return [];
        }

        $positions = explode(',', $this->bg_position);

        return ['x' => $positions[0], 'y' => $positions[1]];
    }

    protected function _postSave()
    {
        /** @var \apathy\StyleSuite\Repository\Styles $repo */
        $repo = $this->repository('apathy\StyleSuite:Styles');

        return $repo->rebuildPostbitStyleCache();
    }

    public static function getStructure(Structure $structure)
    {
        $structure->table = 'xf_ap_ss_postbit_style';
        $structure->shortName = 'apathy\StyleSuite:Postbit';
        $structure->primaryKey = ['style_id','user_id'];
        $structure->columns = [
            'style_id'      => ['type' => self::UINT,  'autoIncrement' => true],
            'user_id'       => ['type' => self::UINT,  'required'      => true, 'default' => XF::visitor()->user_id],
            'disable'       => ['type' => self::BOOL,                           'default' => 0],
            'background'    => ['type' => self::STR,   'maxLength'     => 200,  'default' => false],
            'bg_type'       => ['type' => self::UINT,                           'default' => 0],
            'bg_repeat'     => ['type' => self::STR,   'maxLength'     => 30,   'default' => 0],
            'bg_position'   => ['type' => self::STR,   'maxLength'     => 30,   'default' => false],
            'bg_size'       => ['type' => self::STR,   'maxLength'     => 30,   'default' => false],
            'bg_opacity'    => ['type' => self::UINT,                           'default' => 1],
            'bg_brightness' => ['type' => self::FLOAT,                          'default' => 1.0],
            'bg_contrast'   => ['type' => self::UINT,                           'default' => 1],
            'bg_blur'       => ['type' => self::UINT,                           'default' => 0],
            'bg_date'       => ['type' => self::UINT,                           'default' => XF::$time],
            'color'         => ['type' => self::STR,   'maxLength'     => 30,   'default' => false],
            'text_shadow'   => ['type' => self::BOOL,                           'default' => 0],
            'css'           => ['type' => self::JSON,                           'default' => NULL]
        ];
        $structure->getters = [];
        $structure->relations = [];

        return $structure;
    }
}
