<?php

/**
 *  ▄▄▄·  ▄▄▄· ▄▄▄· ▄▄▄▄▄ ▄ .▄ ▄· ▄▌
 * ▐█ ▀█ ▐█ ▄█▐█ ▀█ •██  ██▪▐█▐█▪██▌
 * ▄█▀▀█  ██▀·▄█▀▀█  ▐█.▪██▀▐█▐█▌▐█▪
 * ▐█ ▪▐▌▐█▪·•▐█ ▪▐▌ ▐█▌·██▌▐▀ ▐█▀·.
 *  ▀  ▀ .▀    ▀  ▀  ▀▀▀ ▀▀▀ ·  ▀ •
 *  <https://fortreeforums.xyz/>
 */

namespace apathy\StyleSuite\Entity;

use XF;
use XF\Mvc\Entity\Entity;
use XF\Mvc\Entity\Structure;

/**
 * COLUMNS
 * @property int    $style_id
 * @property int    $user_id
 * @property string $pr_page_header
 * @property string $pr_navbar_bg
 * @property string $pr_page_bg
 * @property int    $pr_page_bg_type
 * @property int    $pr_page_bg_rep
 * @property string $pr_font_color
 * @property string $pr_url_color
 * @property string $pr_highlight_color
 * @property string $pr_box_header
 * @property string $pr_box_bg
 * @property string $pr_border_color
 * @property string $pr_border_alt_color
 * @property string $pr_button
 * @property string $pr_scrollbar_color
 * @property int    $pr_scrollbar_width
 * @property string $pr_scrollbar_bg
 * @property int    $pr_scrollbar_radius
 * @property string $pr_css
 */

class Profile extends Entity
{
    public static function getStructure(Structure $structure)
    {
        $structure->table = 'xf_ap_profile_styles';
        $structure->shortName = 'apathy\StyleSuite:Profile';
        $structure->primaryKey = ['style_id','user_id'];
        $structure->columns = [
            'style_id'              => ['type' => self::UINT, 'autoIncrement' => true],
            'user_id'               => ['type' => self::UINT, 'required'      => true, 'default' => XF::visitor()->user_id],
            'pr_page_header'        => ['type' => self::STR,  'maxLength'     => 90,   'default' => false],
            'pr_navbar_bg'          => ['type' => self::STR,  'maxLength'     => 30,   'default' => false],
            'pr_page_bg'            => ['type' => self::STR,  'maxLength'     => 90,   'default' => false],
            'pr_page_bg_type'       => ['type' => self::UINT,                          'default' => 0],
            'pr_page_bg_rep'        => ['type' => self::UINT,                          'default' => 0],
            'pr_font_color'         => ['type' => self::STR,  'maxLength'     => 30,   'default' => false],
            'pr_url_color'          => ['type' => self::STR,  'maxLength'     => 30,   'default' => false],
            'pr_highlight_color'    => ['type' => self::STR,  'maxLength'     => 30,   'default' => false],
            'pr_box_header'         => ['type' => self::STR,  'maxLength'     => 30,   'default' => false],
            'pr_box_bg'             => ['type' => self::STR,  'maxLength'     => 30,   'default' => false],
            'pr_border_color'       => ['type' => self::STR,  'maxLength'     => 30,   'default' => false],
            'pr_border_alt_color'   => ['type' => self::STR,  'maxLength'     => 30,   'default' => false],
            'pr_button'             => ['type' => self::STR,  'maxLength'     => 30,   'default' => false],
            'pr_scrollbar_color'    => ['type' => self::STR,  'maxLength'     => 30,   'default' => false],
            'pr_scrollbar_width'    => ['type' => self::UINT,                          'default' => 0],
            'pr_scrollbar_bg'       => ['type' => self::STR,  'maxLength'     => 30,   'default' => false],
            'pr_scrollbar_radius'   => ['type' => self::UINT,                          'default' => 0],
            'pr_css'                => ['type' => self::STR,  'maxLength'     => 9500, 'default' => false]
        ];
        $structure->getters = [];
        $structure->relations = [];

        return $structure;
    }
}
