<?php

/**
 *  ▄▄▄·  ▄▄▄· ▄▄▄· ▄▄▄▄▄ ▄ .▄ ▄· ▄▌
 * ▐█ ▀█ ▐█ ▄█▐█ ▀█ •██  ██▪▐█▐█▪██▌
 * ▄█▀▀█  ██▀·▄█▀▀█  ▐█.▪██▀▐█▐█▌▐█▪
 * ▐█ ▪▐▌▐█▪·•▐█ ▪▐▌ ▐█▌·██▌▐▀ ▐█▀·.
 *  ▀  ▀ .▀    ▀  ▀  ▀▀▀ ▀▀▀ ·  ▀ •
 *  <https://fortreeforums.xyz/>
 */

namespace apathy\StyleSuite\Entity;

use XF;
use XF\Mvc\Entity\Entity;
use XF\Mvc\Entity\Structure;

/**
 * COLUMNS
 * @property int|null $style_id
 * @property int|null $user_id
 * @property bool     $bold
 * @property bool     $italic
 * @property bool     $underline
 * @property int      $color_type
 * @property string   $color
 * @property string   $color_alt
 * @property string   $font
 * @property string   $glow
 * @property string   $glow_alt
 * @property int      $glow_strength
 * @property array    $glow_css
 * @property string   $sparkle
 * @property string   $inner_text_animation
 * @property string   $icon
 * @property int      $icon_type
 * @property string   $icon_color
 * @property bool     $icon_position
 * @property int      $icon_date
 */

class Username extends Entity
{
	public function getAbstractedIconPath($size)
	{
		$userId = $this->user_id;

		return sprintf('data://apathy/StyleSuite/icons/%s/%d/%d.jpg',
			$size,
			floor($userId / 1000),
			$userId
		);
	}

	public function getIconUrl($sizeCode, $canonical = false)
	{
		$app = $this->app();
        $options = $app->options();

		$sizeMap = [
            'l' => $options->apSsMaxIconWidth,
            'm' => round( $options->apSsMaxIconWidth / 1.2 )
        ];

		if(!isset($sizeMap[$sizeCode]))
		{
			$sizeCode = 'l';
		}

		if($this->icon_date)
		{
			$group = floor($this->user_id / 1000);

			return $app->applyExternalDataUrl(
				"apathy/StyleSuite/icons/{$sizeCode}/{$group}/{$this->user_id}.jpg?{$this->icon_date}",
				$canonical
			);
		}

		return null;
	}

    public function getIconDataUrl(bool $canonical = false): string
    {
        $app = $this->app();
        $dataPath = $app->applyExternalDataUrl('apathy/StyleSuite', $canonical);

        return $dataPath . '/icons/';
    }

    protected function _postSave()
    {
        /** @var \apathy\StyleSuite\Repository\Styles $repo */
        $repo = $this->repository('apathy\StyleSuite:Styles');

        $repo->rebuildUsernameStyleCache();
        $repo->rebuildUsernameGlowCache();

        return true;
    }

    public static function getStructure(Structure $structure)
    {
        $structure->table = 'xf_ap_ss_username_style';
        $structure->shortName = 'apathy\StyleSuite:Username';
        $structure->primaryKey = ['style_id','user_id'];
        $structure->columns = [
            'style_id'               => ['type' => self::UINT,  'autoIncrement' => true],
            'user_id'                => ['type' => self::UINT,  'required'      => true, 'default' => XF::visitor()->user_id],
            'bold'                   => ['type' => self::BOOL,                           'default' => 0],
            'italic'                 => ['type' => self::BOOL,                           'default' => 0],
            'underline'              => ['type' => self::BOOL,                           'default' => 0],
            'color_type'             => ['type' => self::UINT,                           'default' => 0],
            'color'                  => ['type' => self::STR,                            'default' => 30],
            'color_alt'              => ['type' => self::STR,                            'default' => 30],
            'font'                   => ['type' => self::STR,   'maxLength'     => 30,   'default' => false],
            'glow'                   => ['type' => self::STR,   'maxLength'     => 30,   'default' => false],
            'glow_alt'               => ['type' => self::STR,   'maxLength'     => 30,   'default' => false],
            'glow_strength'          => ['type' => self::STR,   'maxLength'     => 30,   'default' => false],
            'glow_css'               => ['type' => self::JSON,                           'default' => NULL],
            'sparkle'                => ['type' => self::STR,   'maxLength'     => 30,   'default' => 1.0],
            'inner_text_animation'   => ['type' => self::STR,   'maxLength'     => 200,  'default' => false],
            'icon'                   => ['type' => self::STR,   'maxLength'     => 80,   'default' => false],
            'icon_type'              => ['type' => self::UINT,                           'default' => 0],
            'icon_color'             => ['type' => self::STR,   'maxLength'     => 30,   'default' => 0],
            'icon_position'          => ['type' => self::BOOL,                           'default' => 0],
            'icon_date'              => ['type' => self::UINT,                           'default' => 0]
        ];
        $structure->getters = [];
        $structure->relations = [];

        return $structure;
    }
}
