<?php

/**
 *  ▄▄▄·  ▄▄▄· ▄▄▄· ▄▄▄▄▄ ▄ .▄ ▄· ▄▌
 * ▐█ ▀█ ▐█ ▄█▐█ ▀█ •██  ██▪▐█▐█▪██▌
 * ▄█▀▀█  ██▀·▄█▀▀█  ▐█.▪██▀▐█▐█▌▐█▪
 * ▐█ ▪▐▌▐█▪·•▐█ ▪▐▌ ▐█▌·██▌▐▀ ▐█▀·.
 *  ▀  ▀ .▀    ▀  ▀  ▀▀▀ ▀▀▀ ·  ▀ •
 *  <https://fortreeforums.xyz/>
 */

namespace apathy\StyleSuite;

use XF;

class Helper
{
    public static function cleanUpFontNames($cache): array
    {
        $items = [];

        foreach($cache as $key => $value)
        {
            $name = self::stripFileExtensions($key);

            $items[$name] = $value;
        }

        return $items;
    }

    public static function getDefaultFonts(): array
    {
        return [
            'acknowledge-tt-brk',
            'Aclonica-Regular',
            'BreeSerif-Regular',
            'copperplatecc-heavy',
            'Eater-Regular',
            'FontdinerSwanky-Regular',
            'Nosifer-Regular',
            'PollerOne-Regular',
            'ReggaeOne-Regular',
            'Righteous-Regular',
            'ZenDots-Regular'
        ];
    }

    public static function getDefaultFrames(): array
    {
        return [
            'frame_administrator',
            'frame_gradient1_profile',
            'frame_neon_copper',
            'frame_neon_palate1',
            'frame_rainbow',
            'frame_animated_flames_full',
            'frame_gradient2.',
            'frame_neon_flames',
            'frame_neon_palate2',
            'frame_spring',
            'frame_blue',
            'frame_green',
            'frame_neon_forest',
            'frame_neon_red',
            'frame_tricolour_profile',
            'frame_copper',
            'frame_lightning',
            'frame_neon_gradient',
            'frame_neon_yellow',
            'frame_vip',
            'frame_flames',
            'frame_lightning_profile',
            'frame_neon_gradient1',
            'frame_palate1',
            'frame_flames_profile',
            'frame_member',
            'frame_neon_gradient2',
            'frame_palate2',
            'frame_forest',
            'frame_moderator',
            'frame_neon_green',
            'frame_pastel_rainbow',
            'frame_gradient1',
            'frame_neon_blue',
            'frame_neon_lightning',
            'frame_pokeball'
        ];
    }

    public static function getDefaultPostbitBgs(): array
    {
        return [
            'Green-Pattern',
            'Purple-Circles',
            'Red-Squares'
        ];
    }

    public static function getDefaultSparkles(): array
    {
        return [
            '1',
            '3',
            '4',
            '5',
            '8',
            '9',
            '10',
            '18',
            '20',
            '21',
            '24',
            'sparkle_blue',
            'sparkle_green',
            'sparkle_orange',
            'sparkle_purple',
            'sparkle_red',
            'sparkle_white',
            'sparkle_yellow'
        ];
    }

    public static function getCscnProfileCss(array $props): string
    {
        return '/****** CSCN Annivesary ******/
        .p-navSticky {
            background: '.$props['navbar'].';
            box-shadow: none;
        }

        html {
            background: '.$props['pageBg'].';
        }

        .p-footer {
            box-shadow: none;
        }';
    }

    public static function getIpBeeProfileCss(array $props): string
    {
        return '/****** IPBee Fixes ******/
        .p-nav-list .p-navEl.is-selected .p-navEl-link::after
        {
            border-bottom-color: rgba(0,0,0,0.5) !important;
        }';
    }

    public static function getMxDarkProfileCss(array $props): string
    {
        return '/****** MX Dark Fixes ******/
        .p-footer-copyright > a > .fas.fa-star-and-crescent {
            color: '.$props['highlightColor'].' !important;
        }

        .p-nav-list .p-navEl.is-selected {
            border-bottom: 2px solid '.$props['highlightColor'].';
        }

        .p-navgroup-link {
            border-left: 1px solid '.$props['borderColor'].';
        }';
    }

    public static function getPachProfileCss(array $props): string
    {
        return '/****** Pach Fixes ******/
        .memberHeader {
            background: '.$props['boxBg'].';
        }

        html .button.button--link,
        html a.button.button--link,
        html .button:not(.button--splitTrigger).button--link,
        html a.button:not(.button--splitTrigger).button--link {
            background: '.$props['buttonColor'].' !important;
        }';
    }

    public static function getPigmentGreenProfileCss(array $props): string
    {
        return '/****** PigmentGreen Fixes ******/
        .p-navgroup.p-discovery::before,
        .p-navgroup.p-discovery::after {
            border-color: transparent;
        }

        .p-navgroup-link--search {
            background: '.$props['navbar'].';
        }

        .p-footer-row-opposite::before,
        .p-footer-row-opposite::after {
            border-color: transparent;
        }

        .p-footer-row-opposite {
            background: transparent;
        }

        .p-nav-list .p-navEl.is-selected .p-navEl-link::before {
            border-bottom-color: '.$props['highlightColor'].';
        }';
    }

    public static function getPurpleFreakProfileCss(array $props): string
    {
        return '/****** PurpleFreak Fixes ******/
        .p-nav-inner {
            background: transparent;
        }

        .p-footer-inner {
            background: transparent;
        }';
    }

    public static function getRoyalProfileCss(array $props): string
    {
        return '/****** Royal Fixes ******/
        .p-nav-opposite {
            background: '.$props['navbar'].';
        }

        .p-body-inner {
            background: transparent !important;
        }

        .p-footer-inner {
            background: transparent;
        }';
    }

    public static function getShadesOfXProfileCss(array $props): string
    {
        return '/****** Shades of Grey/Blue Fixes ******/
        .p-nav-list .p-navEl {
            background: transparent;
        }

        .p-navEl-link:hover,
        .p-navEl-splitTrigger:hover {
            background: linear-gradient(rgba(0,0,0,0.5), rgba(0,0,0,0.5)), '.$props['navbar'].' !important;
        }

        .message-responseRow {
            color: '.$props['fontColor'].';
        }

        .p-navgroup-link {
            border-left: 1px solid '.$props['borderColor'].';
        }';
    }

    public static function getStylefactoryRainProfileCss(array $props): string
    {
        return '/****** StyleFactory Rain Fixes ******/
        .p-nav::before {
            content: " ";
            background: url('.$props['header'].');
            height: 200px;
            background-position: 50%;
            display: block;
        }

        .bbWrapper,
        .pairs > dd,
        .u-dt[title] {
            color: '.$props['fontColor'].';
        }

        .message-cell.message-cell--user {
            background: linear-gradient(rgba(0,0,0,0.5), rgba(0,0,0,0.5)), '.$props['boxBg'].' !important;
        }

        .input:hover {
            background: linear-gradient(rgba(0,0,0,0.1), rgba(0,0,0,0.1)), '.$props['boxBg'].';
        }

        .p-body-header {
            border: 3px solid '.$props['highlightColor'].' !important;
        }

        .p-navEl::after {
            border-bottom: 2px solid '.$props['highlightColor'].';
        }

        .iconic > i {
            color: '.$props['highlightColor'].' !important;
        }

        <xf:if is="$xf.options.ap_disable_frame_styles">
            .avatar {
                background: linear-gradient(to right, '.$props['highlightColor'].', '.$props['highlightColor'].');
            }
        </xf:if>

        .message-cell.message-cell--user {
            border-right: 1px solid '.$props['borderColor'].' !important;
        }';
    }

    public static function getThemehouseIoProfileCss(array $props): string
    {
        return '/****** ThemeHouse iO Fixes ******/
        .p-header {
            display: block;
        }

        .block--messages.block .message {
            background: transparent;
        }

        .p-footer-inner,
        .message:not(:last-child)::after,
        .notices.notices--block .notice {
            background: '.$props['boxBg'].';
        }

        .p-footer-linkList.p-footer-choosers a:hover {
            background: linear-gradient(rgba(0,0,0,0.5), rgba(0,0,0,0.5)), '.$props['boxBg'].';
        }

        .notices.notices--block .notice {
            box-shadow: inset 0 0 2px '.$props['highlightColor'].';
        }

        .p-nav-list .p-navEl.is-selected::after,
        .notice.notice--primary .uix_noticeIcon {
            background: '.$props['highlightColor'].';
        }

        .menu-content {
            box-shadow: 0px 10px 20px '.$props['highlightColor'].', '.$props['highlightColor'].' 0px 0px 0px 1px;
        }

        .menu-content::before {
            display: none;
        }

        .notices.notices--block .notice {
            border: 1px solid '.$props['borderColor'].';
        }

        .p-footer-linkList.p-footer-choosers a {
            border: 2px solid '.$props['borderColor'].';
        }';
    }

    public static function getThemehouseUixProfileCss(array $props): string
    {
        return '/****** ThemeHouse UI.X Fixes ******/
        .block--messages.block .message,
        .js-quickReply.block .message,
        .block--messages .block-row,
        .js-quickReply .block-row {
            color: '.$props['fontColor'].' !important;
        }

        .block--messages.block .message,
        .p-footer-copyrightRow  {
            background: '.$props['boxBg'].' !important
        }

        .p-footer-inner {
            background: linear-gradient(rgba(0,0,0,0.5), rgba(0,0,0,0.5)), '.$props['boxBg'].';
        }

        .pageNav-page.pageNav-page--current {
            box-shadow: 0 -2px '.$props['highlightColor'].' inset;
        }

        .actionBar {
            border-top: 0px;
        }

        .p-footer-copyrightRow {
            border: 1px solid '.$props['borderColor'].';
        }

        .uix_extendedFooter {
            background: transparent;
        }';
    }

    public static function proxyImage($url)
    {
        /**
         * @todo
         * This can be improved - it doesn't account for subdomains etc
         */

        $app = XF::app();

        if($app->options()->imageLinkProxy['images'] === true
        && strpos($app->request()->getHostUrl(), $url) === false)
        {
            return $app->service('XF:ImageProxy')->getImage($url);
        }
    }

    /**
     * Strips the following extensions:
     * - .jpeg / .jpg 
     * - .gif 
     * - .png 
     * - .webp 
     * - .ttf 
     * - .otf
     * - .woff
     * - .woff2
     */
    public static function stripFileExtensions(string $file)
    {
        return strtr($file, [
            '.jpeg'  => '',
            '.jpg'   => '',
            '.gif'   => '',
            '.png'   => '',
            '.webp'  => '',
            '.ttf'   => '',
            '.otf'   => '',
            '.woff'  => '',
            '.woff2' => ''
        ]);
    }

    public static function verifyColors(array $colors): bool
    {
        $validator = new XF\Util\Color;

        foreach($colors as $color)
        {
            $color = trim($color);

            if(!strlen($color))
            {
                continue;
            }
            elseif(!$validator->isValidColor($color))
            {
                throw new XF\PrintableException(XF::phrase('ap_ss_please_enter_valid_color'));

                return false;
            }
        }

        return true;
    }

    /**
     * XF\Entity\UserGroup
     */
    public static function verifyCss(&$css): bool
    {
        $css = trim($css);

        if(!strlen($css))
        {
            return true;
        }

        $parser = new \Less_Parser();

        try
        {
            $parser->parse('.example { ' . $css . '}')->getCss();
        }
        catch(\Exception $e)
        {
            throw new XF\PrintableException(XF::phrase('ap_ss_please_enter_valid_css'));

            return false;
        }

        return true;
    }

    public static function verifyUrl(string $url): bool
    {
        $url = trim($url);

        $validator = XF::app()->validator('Url');

        if(!strlen($url))
        {
            return true;
        }
        elseif(!$validator->isValid($url))
        {
            throw new XF\PrintableException(XF::phrase('please_enter_valid_url'));

            return false;
        }

        return true;
    }
}
