<?php

/**
 *  ▄▄▄·  ▄▄▄· ▄▄▄· ▄▄▄▄▄ ▄ .▄ ▄· ▄▌
 * ▐█ ▀█ ▐█ ▄█▐█ ▀█ •██  ██▪▐█▐█▪██▌
 * ▄█▀▀█  ██▀·▄█▀▀█  ▐█.▪██▀▐█▐█▌▐█▪
 * ▐█ ▪▐▌▐█▪·•▐█ ▪▐▌ ▐█▌·██▌▐▀ ▐█▀·.
 *  ▀  ▀ .▀    ▀  ▀  ▀▀▀ ▀▀▀ ·  ▀ •
 *  <https://fortreeforums.xyz/>
 */

namespace apathy\StyleSuite\Install;

trait Table
{
    protected function getTables(): array
    {
        $tables = [];

        $tables['xf_ap_ss_postbit_style'] = function($table)
        {
            $table->addColumn('style_id', 'int')->autoIncrement();
            $table->addPrimaryKey('style_id');

            $table->addColumn('user_id', 'int');
            $table->addColumn('disable', 'bool')->setDefault(0);
            $table->addColumn('background', 'varchar', 200);
            $table->addColumn('bg_type', 'int')->setDefault(0);
            $table->addColumn('bg_repeat', 'varchar', 30);
            $table->addColumn('bg_position', 'varchar', 30);
            $table->addColumn('bg_size', 'varchar', 30);
            $table->addColumn('bg_opacity', 'int')->setDefault(1);
            $table->addColumn('bg_brightness', 'float')->setDefault(1.0);
            $table->addColumn('bg_contrast', 'int')->setDefault(1);
            $table->addColumn('bg_date', 'int')->setDefault(0);
            $table->addColumn('color', 'varchar', 30);
            $table->addColumn('text_shadow', 'bool')->setDefault(0);
            $table->addColumn('css', 'blob')->nullable()->setDefault(null);
        };

        $tables['xf_ap_profile_styles'] = function($table)
        {
            $table->addColumn('style_id', 'int')->autoIncrement();
            $table->addPrimaryKey('style_id');

            $table->addColumn('user_id', 'int');
            $table->addColumn('pr_page_header', 'varchar', 90);
            $table->addColumn('pr_navbar_bg', 'varchar', 30);
            $table->addColumn('pr_page_bg', 'varchar', 90);
            $table->addColumn('pr_page_bg_type', 'int')->setDefault(0);
            $table->addColumn('pr_page_bg_rep', 'int')->setDefault(0);
            $table->addColumn('pr_font_color', 'varchar', 30);
            $table->addColumn('pr_url_color', 'varchar', 30);
            $table->addColumn('pr_highlight_color', 'varchar', 30);
            $table->addColumn('pr_box_header', 'varchar', 30);
            $table->addColumn('pr_box_bg', 'varchar', 30);
            $table->addColumn('pr_border_color', 'varchar', 30);
            $table->addColumn('pr_border_alt_color', 'varchar', 30);
            $table->addColumn('pr_button', 'varchar', 30);
            $table->addColumn('pr_scrollbar_color', 'varchar', 30);
            $table->addColumn('pr_scrollbar_width', 'int')->setDefault(0);
            $table->addColumn('pr_scrollbar_bg', 'varchar', 30);
            $table->addColumn('pr_scrollbar_radius', 'int')->setDefault(0);
            $table->addColumn('pr_css', 'varchar', 9500);
        };

        $tables['xf_ap_ss_username_style'] = function($table)
        {
            $table->addColumn('style_id', 'int')->autoIncrement();
            $table->addPrimaryKey('style_id');

            $table->addColumn('user_id', 'int');
            $table->addColumn('bold', 'bool')->setDefault(0);
            $table->addColumn('italic', 'bool')->setDefault(0);
            $table->addColumn('underline', 'bool')->setDefault(0);
            $table->addColumn('color_type', 'int')->setDefault(0);
            $table->addColumn('color', 'varchar', 30);
            $table->addColumn('color_alt', 'varchar', 30);
            $table->addColumn('font', 'varchar', 30);
            $table->addColumn('glow', 'varchar', 30);
            $table->addColumn('glow_alt', 'varchar', 30);
            $table->addColumn('glow_strength', 'int')->setDefault(0);
            $table->addColumn('glow_css', 'blob')->nullable()->setDefault(NULL);
            $table->addColumn('sparkle', 'varchar', 30);
            $table->addColumn('inner_text_animation', 'varchar', 200);
            $table->addColumn('icon', 'varchar', 80);
            $table->addColumn('icon_type', 'int')->setDefault(0);
            $table->addColumn('icon_color', 'varchar', 30);
            $table->addColumn('icon_position', 'bool')->setDefault(0);
            $table->addColumn('icon_date', 'int')->setDefault(0);
        };

        $tables['xf_ap_user_style_ignored'] = function($table)
        {
            $table->addColumn('user_id', 'int');
            $table->addColumn('ignored_user_id', 'int');
        };

        $tables['xf_ap_profile_block'] = function($table)
        {
            $table->addColumn('block_id', 'int')->autoIncrement();
            $table->addColumn('user_id', 'int');
            $table->addColumn('title', 'varchar', 40);
            $table->addColumn('type', 'varchar', 20);
            $table->addColumn('fa_icon', 'varchar', 30);
            $table->addColumn('content', 'varchar', 500);
            $table->addColumn('position', 'int')->setDefault(0);
            $table->addColumn('active', 'bool')->setDefault(1);
        };

        return $tables;
    }

    protected function getAlteredTables(): array
    {
        $tables = [];

        $tables['xf_user'] = function($table)
        {
            $table->addColumn('ap_username_style', 'blob')->nullable()->setDefault(NULL);
            $table->addColumn('ap_title_style', 'blob')->nullable()->setDefault(NULL);
            $table->addColumn('ap_postbit_style', 'blob')->nullable()->setDefault(NULL);
            $table->addColumn('ap_post_style', 'blob')->nullable()->setDefault(NULL);
            $table->addColumn('ap_tooltip_style', 'blob')->nullable()->setDefault(NULL);
            $table->addColumn('ap_frame', 'varchar', 30)->setDefault('');
        };

        $tables['xf_user_group'] = function($table)
        {
            $table->addColumn('ap_frame', 'varchar', 30)->setDefault('');
        };

        $tables['xf_user_option'] = function($table)
        {
            $table->addColumn('ap_ss_disable_user_styles', 'bool')->setDefault(0);
        };

        /**
         * [tl] Social Groups
         */
        $addons = $this->app->container('addon.cache');
        $tlGroups = array_key_exists('Truonglv/Groups', $addons);

        if($tlGroups)
        {
            $tables['xf_tl_group'] = function($table)
            {
                $table->addColumn('ap_group_style', 'blob')->nullable()->setDefault(NULL);
            };
        }

        return $tables;
    }

    protected function dropAlteredTableColumns(): array
    {
        $tables = [];

        $tables['xf_user'] = function($table)
        {
            $table->dropColumns([
                'ap_username_style',
                'ap_title_style',
                'ap_postbit_style',
                'ap_post_style',
                'ap_tooltip_style',
                'ap_frame'
            ]);
        };

        $tables['xf_user_group'] = function($table)
        {
            $table->dropColumns(['ap_frame']);
        };

        $tables['xf_user_option'] = function($table)
        {
            $table->dropColumns(['ap_ss_disable_user_styles']);
        };

        /**
         * [tl] Social Groups
         */
        $addons = $this->app->container('addon.cache');
        $tlGroups = array_key_exists('Truonglv/Groups', $addons);

        if($tlGroups)
        {
            $tables['xf_tl_group'] = function($table)
            {
                $table->dropColumns(['ap_group_style']);
            };
        }

        return $tables;
    }
}
