<?php

/**
 *  ▄▄▄·  ▄▄▄· ▄▄▄· ▄▄▄▄▄ ▄ .▄ ▄· ▄▌
 * ▐█ ▀█ ▐█ ▄█▐█ ▀█ •██  ██▪▐█▐█▪██▌
 * ▄█▀▀█  ██▀·▄█▀▀█  ▐█.▪██▀▐█▐█▌▐█▪
 * ▐█ ▪▐▌▐█▪·•▐█ ▪▐▌ ▐█▌·██▌▐▀ ▐█▀·.
 *  ▀  ▀ .▀    ▀  ▀  ▀▀▀ ▀▀▀ ·  ▀ •
 *  <https://fortreeforums.xyz/>
 */

namespace apathy\StyleSuite\Install;

use XF\Db\Schema\Alter;

trait upgrade2080170
{
    public function upgrade2080170Step1()
    {
        $this->schemaManager()->alterTable('xf_ap_ss_postbit_style', function(Alter $table)
        {
            $table->changeColumn('background', 'varchar', 200);
        });
    }

	protected function postUpgrade2080170($previousVersion, array &$stateChanges)
	{
        if(!$this->schemaManager()->columnExists('xf_user', 'ap_postbit_style'))
        {
            return;
        }

        $this->populatePostbitEntity();
	}

    protected function populatePostbitEntity()
    {
        $app = $this->app();

        $postbits = $app->finder('apathy\StyleSuite:Postbit')->fetch();

        if($postbits || !empty($postbits))
        {
            return;
        }

        $finder = $app->finder('XF:User')
                      ->where('ap_postbit_style', '!=', NULL)
                      ->where('ap_postbit_style', '!=', '[]')
                      ->fetch();

        foreach($finder as $user)
        {
            $style = $user->ap_postbit_style;

            if(isset($style['pbit_bg']))
            {
                if(strlen($style['pbit_bg']) >= 201)
                {
                    $style['pbit_bg'] = '';
                }
            }

            $input = [
                'user_id'       => $user['userId'],
                'disable'       => $style['pbit_disable']       ?? 0,
                'background'    => $style['pbit_bg']            ?? '',
                'bg_type'       => $style['pbit_bg_type']       ?? 0,
                'bg_repeat'     => $style['pbit_bg_rep']        ?? 'repeat',
                'bg_position'   => $style['pbit_bg_pos']        ?? 'center',
                'bg_size'       => $style['pbit_bg_size']       ?? 'size',
                'bg_opacity'    => $style['pbit_bg_opacity']    ?? 100,
                'bg_brightness' => $style['pbit_bg_brightness'] ?? 1.0,
                'bg_contrast'   => $style['pbit_bg_contrast']   ?? 100,
                'color'         => $style['pbit_color']         ?? '',
                'text_shadow'   => $style['pbit_shadow']        ?? 0,
                'css'           => $style['pbit_css']           ?? ''
            ];

            $entity = $app->em()->create('apathy\StyleSuite:Postbit');

            $entity->bulkSet($input);

            $entity->save();
        }
    }
}
