<?php

/**
 *  ▄▄▄·  ▄▄▄· ▄▄▄· ▄▄▄▄▄ ▄ .▄ ▄· ▄▌
 * ▐█ ▀█ ▐█ ▄█▐█ ▀█ •██  ██▪▐█▐█▪██▌
 * ▄█▀▀█  ██▀·▄█▀▀█  ▐█.▪██▀▐█▐█▌▐█▪
 * ▐█ ▪▐▌▐█▪·•▐█ ▪▐▌ ▐█▌·██▌▐▀ ▐█▀·.
 *  ▀  ▀ .▀    ▀  ▀  ▀▀▀ ▀▀▀ ·  ▀ •
 *  <https://fortreeforums.xyz/>
 */

namespace apathy\StyleSuite\Install;

use XF\Db\Schema\Alter;
use XF\Db\Schema\Create;

trait upgrade2090070
{
    public function upgrade2090070Step1()
    {
        $schemaManager = $this->schemaManager();

        $schemaManager->alterTable('xf_user', function(Alter $table)
        {
            $table->dropColumns('ap_postbit_style');
        });

        $schemaManager->alterTable('xf_ap_ss_postbit_style', function(Alter $table)
        {
            $table->addUniqueKey('user_id');
        });

        $schemaManager->createTable('xf_ap_ss_username_style', function(Create $table)
        {
            $table->addColumn('style_id', 'int')->autoIncrement();
            $table->addPrimaryKey('style_id');

            $table->addColumn('user_id', 'int');
            $table->addUniqueKey('user_id');

            $table->addColumn('bold', 'bool')->setDefault(0);
            $table->addColumn('italic', 'bool')->setDefault(0);
            $table->addColumn('underline', 'bool')->setDefault(0);
            $table->addColumn('color_type', 'int')->setDefault(0);
            $table->addColumn('color', 'varchar', 30);
            $table->addColumn('color_alt', 'varchar', 30);
            $table->addColumn('font', 'varchar', 30);
            $table->addColumn('glow', 'varchar', 30);
            $table->addColumn('glow_alt', 'varchar', 30);
            $table->addColumn('glow_strength', 'int')->setDefault(0);
            $table->addColumn('glow_css', 'blob')->nullable()->setDefault(NULL);
            $table->addColumn('sparkle', 'varchar', 30);
            $table->addColumn('inner_text_animation', 'varchar', 200);
            $table->addColumn('icon', 'varchar', 80);
            $table->addColumn('icon_type', 'int')->setDefault(0);
            $table->addColumn('icon_color', 'varchar', 30);
            $table->addColumn('icon_position', 'bool')->setDefault(0);
            $table->addColumn('icon_date', 'int')->setDefault(0);
        });
    }

	protected function postUpgrade2090070($previousVersion, array &$stateChanges)
	{
        $schemaManager = $this->schemaManager();

        if(!$schemaManager->columnExists('xf_user', 'ap_username_style'))
        {
            return;
        }

        $this->populateUsernameEntity();
    }

    protected function populateUsernameEntity()
    {
        $app = $this->app();

        $usernames = $app->finder('apathy\StyleSuite:Username')->fetch();

        if($usernames || !empty($usernames))
        {
            return;
        }

        $finder = $app->finder('XF:User')
                      ->where('ap_username_style', '!=', NULL)
                      ->where('ap_username_style', '!=', '[]')
                      ->fetch();

        foreach($finder as $user)
        {
            $style = $user->ap_username_style;

            if(isset($style['uname_bg']))
            {
                if(strlen($style['uname_bg']) >= 201)
                {
                    $style['uname_bg'] = '';
                }
            }

            if(isset($style['uname_icon']))
            {
                if(strlen($style['uname_icon']) >= 80)
                {
                    $style['uname_icon'] = '';
                }
            }

            $input = [
                'user_id'              => $user->user_id,
                'bold'                 => $style['uname_bold']          ?? 0,
                'italic'               => $style['uname_italic']        ?? 0,
                'underline'            => $style['uname_underline']     ?? 0,
                'color_type'           => $style['uname_color_type']    ?? 0,
                'color'                => $style['uname_color']         ?? '',
                'color_alt'            => $style['uname_color_end']     ?? '',
                'font'                 => $style['uname_font']          ?? '',
                'glow'                 => $style['uname_glow']          ?? '',
                'glow_alt'             => $style['uname_glow_alt']      ?? '',
                'glow_strength'        => $style['uname_glow_str']      ?? 0,
                'glow_css'             => $style['uname_glow_css']      ?? [],
                'sparkle'              => $style['uname_sparkle']       ?? '',
                'inner_text_animation' => $style['uname_bg']            ?? '',
                'icon'                 => $style['uname_icon']          ?? '',
                'icon_type'            => $style['uname_icon_type']     ?? 0,
                'icon_color'           => $style['uname_icon_clr']      ?? '',
                'icon_position'        => $style['uname_icon_pos']      ?? 0,
            ];

            $entity = $app->em()->create('apathy\StyleSuite:Username');

            $entity->bulkSet($input);

            $entity->save();
        }
    }
}
