<?php

/**
 *  ▄▄▄·  ▄▄▄· ▄▄▄· ▄▄▄▄▄ ▄ .▄ ▄· ▄▌
 * ▐█ ▀█ ▐█ ▄█▐█ ▀█ •██  ██▪▐█▐█▪██▌
 * ▄█▀▀█  ██▀·▄█▀▀█  ▐█.▪██▀▐█▐█▌▐█▪
 * ▐█ ▪▐▌▐█▪·•▐█ ▪▐▌ ▐█▌·██▌▐▀ ▐█▀·.
 *  ▀  ▀ .▀    ▀  ▀  ▀▀▀ ▀▀▀ ·  ▀ •
 *  <https://fortreeforums.xyz/>
 */

namespace apathy\StyleSuite\Install;

use XF\Db\Schema\Alter;

trait upgrade2090570
{
    public function upgrade2090570Step1()
    {
        $schemaManager = $this->schemaManager();

        $schemaManager->alterTable('xf_user', function(Alter $table)
        {
            $table->changeColumn('ap_frame')->resetDefinition()
                  ->type('varchar', 30)->setDefault('');
        });
    }

    /**
     * We're reordering our $glow_strength values to fix a bug
     * where having "weak" / 0 selected would cause the form to
     * default to "None" incorrectly.
     */
	protected function postUpgrade2090570($previousVersion, array &$stateChanges)
	{
        if($previousVersion <= 2090470)
        {
            $this->updateTitleGlowStrengths();
            $this->updateUsernameGlowStrengths();
        }
    }

    protected function updateUsernameGlowStrengths()
    {
        $users = $this->app()->finder('apathy\StyleSuite:Username')->fetch()->toArray();

        if(empty($users))
        {
            return;
        }

        foreach($users as $user)
        {
            switch($user->glow_strength)
            {
                case 0: // Weak
                    $user->glow_strength = 1;
                break;
                case 1: // Medium
                    $user->glow_strength = 2;
                break;
                case 2: // Strong
                    $user->glow_strength = 3;
                break;
                case 3: // CSS
                    $user->glow_strength = 5;
                break;
                case 5: // None
                    $user->glow_strength = 0;
                break;
            }

            $user->save(true, false);
        }
    }

    protected function updateTitleGlowStrengths()
    {
        $users = $this->app()
                      ->finder('XF:User')
                      ->where('ap_title_style', '!=', '[]')
                      ->fetch()
                      ->toArray();

        if(empty($users))
        {
            return;
        }

        foreach($users as $user)
        {
            $style = $user->ap_title_style;
            
            switch($style['ttl_glow_str'])
            {
                case 0: // Weak
                    $style['ttl_glow_str'] = 1;
                break;
                case 1: // Medium
                    $style['ttl_glow_str'] = 2;
                break;
                case 2: // Strong
                    $style['ttl_glow_str'] = 3;
                break;
                case 3: // CSS
                    $style['ttl_glow_str'] = 5;
                break;
                case 5: // None
                    $style['ttl_glow_str'] = 0;
                break;
            }

            $user->ap_title_style = $style;

            $user->save(true, false);
        }
    }
}
