<?php

/**
 *  ▄▄▄·  ▄▄▄· ▄▄▄· ▄▄▄▄▄ ▄ .▄ ▄· ▄▌
 * ▐█ ▀█ ▐█ ▄█▐█ ▀█ •██  ██▪▐█▐█▪██▌
 * ▄█▀▀█  ██▀·▄█▀▀█  ▐█.▪██▀▐█▐█▌▐█▪
 * ▐█ ▪▐▌▐█▪·•▐█ ▪▐▌ ▐█▌·██▌▐▀ ▐█▀·.
 *  ▀  ▀ .▀    ▀  ▀  ▀▀▀ ▀▀▀ ·  ▀ •
 *  <https://fortreeforums.xyz/>
 */

namespace apathy\StyleSuite\Job;

use XF;
use XF\Job\AbstractRebuildJob;
use XF\Util\File;

class Postbit extends AbstractRebuildJob
{
    protected function getNextIds($start, $batch)
    {
        $db = $this->app->db();

        return $db->fetchAllColumn($db->limit(
            "SELECT user_id
            FROM xf_ap_ss_postbit_style
            WHERE user_id > ?
            ORDER BY user_id
            ", $batch
        ), $start);
    }

    protected function rebuildById($id)
    {
        /** @var \XF\Entity\User $user */
        $user = $this->app->em()->find('XF:User', $id);

        if(!$user)
        {
            return;
        }

        $style = $user->PostbitStyle;

        if(!$style
        || empty($style['background'])
        || !preg_match('/http(s):\/\//is', $style['background'])
        || !$user->canChangePostbitStyle())
        {
            return;
        }

        /** @var \apathy\StyleSuite\Service\User\Postbit $service */
        $service = $this->app->service('apathy\StyleSuite:User\Postbit', $user, $style);

        /** @var \apathy\StyleSuite\Repository\Styles $repo */
        $repo = $this->app->repository('apathy\StyleSuite:Styles');

        /** Download the image and retrieve the filename */
        $image = fopen($style['background'], 'r');
        $filename = pathinfo($style['background'], PATHINFO_BASENAME);

        /** Rename the temp file to the images actual name */
        $tempFile = File::copyStreamToTempFile($image);
        $renamedTempFile = File::getTempDir() . XF::$DS . $filename;

        File::renameFile($tempFile, $renamedTempFile);

        /** Run the image through the postbit service */
        $image = new XF\Http\Upload($renamedTempFile, $filename);

        $style->background = $repo->uploadPostbitImage($service, $style, $image);
        $style->save(true, false);
    }

    protected function getStatusType()
    {
        return XF::phrase('ap_ss_rebuilding_postbits');
    }
}
