<?php

/**
 *  ▄▄▄·  ▄▄▄· ▄▄▄· ▄▄▄▄▄ ▄ .▄ ▄· ▄▌
 * ▐█ ▀█ ▐█ ▄█▐█ ▀█ •██  ██▪▐█▐█▪██▌
 * ▄█▀▀█  ██▀·▄█▀▀█  ▐█.▪██▀▐█▐█▌▐█▪
 * ▐█ ▪▐▌▐█▪·•▐█ ▪▐▌ ▐█▌·██▌▐▀ ▐█▀·.
 *  ▀  ▀ .▀    ▀  ▀  ▀▀▀ ▀▀▀ ·  ▀ •
 *  <https://fortreeforums.xyz/>
 */

namespace apathy\StyleSuite;

use apathy\StyleSuite\Helper;
use XF;
use XF\App;
use XF\Container;
use XF\Mvc\Entity\Entity;
use XF\Mvc\Entity\Manager;
use XF\Mvc\Entity\Structure;
use XF\Template\Templater;

class Listener
{
    protected static $_productId = 1;

    public static function appSetup(App $app)
    {
        $container = $app->container();

        $container['ap.avatarFrames'] = $app->fromRegistry('apAvatarFrames',
            function (Container $c)
            {
                return $c['em']->getRepository('apathy\StyleSuite:Styles')->rebuildFrameCache();
            }
        );

        $container['ap.fonts'] = $app->fromRegistry('apFonts',
            function (Container $c)
            {
                return $c['em']->getRepository('apathy\StyleSuite:Styles')->rebuildFontCache();
            }
        );

        $container['ap.sparkles'] = $app->fromRegistry('apSparkles',
            function (Container $c)
            {
                return $c['em']->getRepository('apathy\StyleSuite:Styles')->rebuildSparkleCache();
            }
        );

        $container['ap.unameStyles'] = $app->fromRegistry('apUnameStyles',
            function (Container $c)
            {
                return $c['em']->getRepository('apathy\StyleSuite:Styles')->rebuildUsernameStyleCache();
            }
        );

        $container['ap.unameGlows'] = $app->fromRegistry('apUnameGlows',
            function (Container $c)
            {
                return $c['em']->getRepository('apathy\StyleSuite:Styles')->rebuildUsernameGlowCache();
            }
        );

        $container['ap.titleStyles'] = $app->fromRegistry('apTitleStyles',
            function (Container $c)
            {
                return $c['em']->getRepository('apathy\StyleSuite:Styles')->rebuildCustomTitleStyleCache();
            }
        );

        $container['ap.titleGlows'] = $app->fromRegistry('apTitleGlows',
            function (Container $c)
            {
                return $c['em']->getRepository('apathy\StyleSuite:Styles')->rebuildCustomTitleGlowCache();
            }
        );

        $container['ap.tooltips'] = $app->fromRegistry('apTooltips',
            function (Container $c)
            {
                return $c['em']->getRepository('apathy\StyleSuite:Styles')->rebuildTooltipStyleCache();
            }
        );

        $container['ap.postbitBgs'] = $app->fromRegistry('apPostbitBgs',
            function(Container $c)
            {
                return $c['em']->getRepository('apathy\StyleSuite:Styles')->rebuildPostbitPresetCache();
            }
        );
    }

    public static function appPubSetup(App $app)
    {
        $branding = $app->offsetExists('apathy_branding') ? $app->apathy_branding : [];

        $branding[] = self::$_productId;

        $app->apathy_branding = $branding;
    }

    public static function criteriaUser($rule, array $data, \XF\Entity\User $user, &$returnValue)
    {
        switch($rule)
        {
            case 'has_set_frame':
                if(!empty($user->ap_frame))
                {
                    $returnValue = true;
                }
                break;
            case 'has_uname_style':
                if(!empty($user->ap_username_style))
                {
                    $returnValue = true;
                }
                break;
            case 'has_ttl_style':
                if(!empty($user->ap_title_style))
                {
                    $returnValue = true;
                }
                break;
            case 'has_pbit_style':
                if($user->hasPostbitStyle())
                {
                    $returnValue = true;
                }
                break;
            case 'has_ttip_style':
                if(!empty($user->ap_tooltip_style))
                {
                    $returnValue = true;
                }
                break;
            case 'has_pr_style':
                $profileStyle = XF::app()->em()->findOne('apathy\StyleSuite:Profile', [
                    'user_id' => $user->user_id
                ]);

                if($profileStyle)
                {
                    $returnValue = true;
                }
                break;
        }
    }

    public static function userEntityPostSave(Entity $entity)
    {
        /** @var \apathy\StyleSuite\Repository\Styles $repo */
        $repo = XF::repository('apathy\StyleSuite:Styles');

        if($entity->isUpdate() && $entity->isChanged('ap_title_style'))
        {
            $repo->rebuildCustomTitleStyleCache();
            $repo->rebuildCustomTitleGlowCache();
        }

        if($entity->isUpdate() && $entity->isChanged('ap_tooltip_style'))
        {
            $repo->rebuildTooltipStyleCache();
        }
    }

    public static function userEntityStructure(Manager $em, Structure &$structure)
    {
        /**
         * @todo
         * Migrate username, title, post, tooltip styles
         * into entities & getters.
         */
        $structure->columns['ap_username_style'] = [
            'type'      => Entity::JSON,
            'default'   => []
        ];
        $structure->columns['ap_title_style'] = [
            'type'      => Entity::JSON,
            'default'   => []
        ];
        $structure->columns['ap_post_style'] = [
            'type'      => Entity::JSON,
            'default'   => []
        ];
        $structure->columns['ap_tooltip_style'] = [
            'type'      => Entity::JSON,
            'default'   => []
        ];
        
        $structure->columns['ap_frame'] = [
            'type'      => Entity::STR,
            'maxLength' => 30,
            'default'   => false
        ];
        $structure->getters['postbit_style'] = [
            'getter' => 'getPostbitStyle', 
            'cache'  => true
        ];
        $structure->getters['username_style'] = [
            'getter' => 'getUsernameStyle', 
            'cache'  => true
        ];

        $structure->relations['Block'] = [
            'type'       => Entity::TO_MANY,
            'entity'     => 'apathy\StyleSuite:Block',
            'conditions' => [['user_id', '=', '$user_id']]
        ];
        $structure->relations['UserStyleIgnored'] = [
            'type'       => Entity::TO_MANY,
            'entity'     => 'apathy\StyleSuite:UserStyleIgnored',
            'conditions' => [['user_id', '=', '$user_id']]
        ];
        $structure->relations['PostbitStyle'] = [
            'type'       => Entity::TO_ONE,
            'entity'     => 'apathy\StyleSuite:Postbit',
            'conditions' => [['user_id', '=', '$user_id']]
        ];
        $structure->relations['ProfileStyle'] = [
            'type'       => Entity::TO_ONE,
            'entity'     => 'apathy\StyleSuite:Profile',
            'conditions' => [['user_id', '=', '$user_id']]
        ];
        $structure->relations['UsernameStyle'] = [
            'type'       => Entity::TO_ONE,
            'entity'     => 'apathy\StyleSuite:Username',
            'conditions' => [['user_id', '=', '$user_id']]
        ];
    }

    public static function userGroupEntityStructure(Manager $em, Structure &$structure)
    {
        $structure->columns['ap_frame'] = [
            'type'      => Entity::STR,
            'maxLength' => 30,
            'default'   => false
        ];
    }

    public static function userOptionEntityStructure(Manager $em, Structure &$structure)
    {
        $structure->columns['ap_ss_disable_user_styles'] = [
            'type'    => Entity::BOOL,
            'default' => 0
        ];
    }

    public static function templaterMacroPreRender(Templater $templater, &$type, &$template,
    &$name, &$arguments, &$globalVars)
    {
        if($arguments['group']->group_id == 'ap_ss_frame')
        {
            $template = 'ap_ss_user_edit_frame';
        }
        elseif($arguments['group']->group_id == 'ap_ss_custom_title')
        {
            $template = 'ap_ss_user_edit_custom_title';
        }
        elseif($arguments['group']->group_id == 'ap_ss_postbit')
        {
            $template = 'ap_ss_user_edit_postbit';
        }
        elseif($arguments['group']->group_id == 'ap_ss_profile')
        {
            $template = 'ap_ss_user_edit_profile';
        }
        elseif($arguments['group']->group_id == 'ap_ss_tooltip')
        {
            $template = 'ap_ss_user_edit_tooltip';
        }
        elseif($arguments['group']->group_id == 'ap_ss_username')
        {
            $template = 'ap_ss_user_edit_username';
        }
    }

    public static function templaterSetup(Container $container, Templater &$templater)
    {
        $class = XF::extendClass('apathy\StyleSuite\Template\TemplaterSetup');
        $templaterSetup = new $class();

        $extraFunctions = [
            'usernameletterstyle' => [$templaterSetup, 'fnUsernameLetterStyle'],
            'postbitfilters'      => [$templaterSetup, 'fnPostbitFilters'],
            'postbitstyle'        => [$templaterSetup, 'fnPostbitStyle'],
            'poststyle'           => [$templaterSetup, 'fnPostStyle'],
            'usernameicon'        => [$templaterSetup, 'fnUsernameIcon']
        ];

        $templater->addFunctions($extraFunctions);
    }

    /**
      * Check the response type and return early if its json.
      * This fixes a long standing bug with Siropu Chat 2
      * where opening a user profile in an overlay through the chat
      * would cause the page style to switch to the viewed members custom style.
      */
    public static function templaterTemplatePreRender(Templater $templater, &$type, &$template, array &$params)
    {
        $app = XF::app();

        $request = $app->request();
        $responseType = $request->filter('_xfResponseType', 'str');

        if($type !== 'public'
        || $template !== 'member_view'
        || $responseType == 'json')
        {
            return;
        }

        $user = $params['user'];

        /** @var \apathy\StyleSuite\XF\Entity\User $visitor */
        $visitor = XF::visitor();

        if(!$user->canChangeProfileStyle()
        || $visitor->isIgnoringStyle($user)
        || $user->ProfileStyle == NULL)
        {
            return;
        }

        $theme = $app->style($visitor->style_id);

        if($theme->getProperty('apSsDisableProfileStyles'))
        {
            return;
        }

        $style = $user->ProfileStyle;

        $props = [
            'header'          => htmlspecialchars($style['pr_page_header']),
            'navbar'          => $style['pr_navbar_bg'],
            'pageBg'          => htmlspecialchars($style['pr_page_bg']),
            'pageBgType'      => $style['pr_page_bg_type'],
            'pageBgRepeat'    => $style['pr_page_bg_rep'],
            'fontColor'       => $style['pr_font_color'],
            'urlColor'        => $style['pr_url_color'],
            'highlightColor'  => $style['pr_highlight_color'],
            'boxHeader'       => $style['pr_box_header'],
            'boxBg'           => $style['pr_box_bg'],
            'altBg'           => 'linear-gradient(rgba(0,0,0,0.5), rgba(0,0,0,0.5)), '.$style['pr_box_bg'],
            'borderColor'     => $style['pr_border_color'],
            'borderAltColor'  => $style['pr_border_alt_color'],
            'buttonColor'     => $style['pr_button'],
            'scrollbarColor'  => $style['pr_scrollbar_color'],
            'scrollbarWidth'  => intval($style['pr_scrollbar_width']),
            'scrollbarBg'     => $style['pr_scrollbar_bg'],
            'scrollbarRadius' => intval($style['pr_scrollbar_radius']),
            'css'             => $style['pr_css']
        ];

        $parser = new \Less_Parser();

        $css = $templater->includeTemplate('public:ap_ss_profile_style.less', ['style' => $props]);

        $theme = $app->em()->find('XF:Style', $visitor->style_id);
        $name  = $theme->title ?? 'Default style';

        switch(true)
        {
            default:
            case ( $name === 'Default style' ):
            break;
            case ( strpos('CSCN', $name) !== false ):
                $css .= $parser->parse(Helper::getCscnProfileCss($props))->getCss();
            break;
            case ( strpos('IPBee', $name) !== false ):
                $css .= $parser->parse(Helper::getIpBeeProfileCss($props))->getCss();
            break;
            case ( strpos('MX Dark', $name) !== false ):
                $css .= $parser->parse(Helper::getMxDarkProfileCss($props))->getCss();
            break;
            case ( strpos('Pach', $name) !== false ):
                $css .= $parser->parse(Helper::getPachProfileCss($props))->getCss();
            break;
            case ( strpos('PigmentGreen', $name) !== false ):
                $css .= $parser->parse(Helper::getPigmentGreenProfileCss($props))->getCss();
            break;
            case ( strpos('PurpleFreak', $name) !== false ):
                $css .= $parser->parse(Helper::getPurpleFreakProfileCss($props))->getCss();
            break;
            case ( strpos('Royal', $name) !== false ):
                $css .= $parser->parse(Helper::getRoyalProfileCss($props))->getCss();
            break;
            case ( strpos('Shades of', $name) !== false ):
                $css .= $parser->parse(Helper::getShadesOfXProfileCss($props))->getCss();
            break;
            case ( strpos('Rain', $name) !== false ):
                $css .= $parser->parse(Helper::getStylefactoryRainProfileCss($props))->getCss();
            break;
            case ( strpos('ThemeHouse iO', $name) !== false ):
                $css .= $parser->parse(Helper::getThemehouseIoProfileCss($props))->getCss();
            break;
            case ( strpos('UI.X', $name) !== false ):
                $css .= $parser->parse(Helper::getThemehouseUixProfileCss($props))->getCss();
            break;
        }

        $templater->inlineCss($css);
    }

    public static function socialGroupPostInstall(XF\AddOn\AddOn $addOn,
    XF\Entity\AddOn $installedAddOn, array $json, array &$stateChanges)
    {
        if($addOn->getAddOnId() == 'Truonglv/Groups')
        {
            $setup = new Setup($addOn, XF::app());
            $setup->upgrade1050070Step1();
        }

        return;
    }
}
