<?php

/**
 *  ▄▄▄·  ▄▄▄· ▄▄▄· ▄▄▄▄▄ ▄ .▄ ▄· ▄▌
 * ▐█ ▀█ ▐█ ▄█▐█ ▀█ •██  ██▪▐█▐█▪██▌
 * ▄█▀▀█  ██▀·▄█▀▀█  ▐█.▪██▀▐█▐█▌▐█▪
 * ▐█ ▪▐▌▐█▪·•▐█ ▪▐▌ ▐█▌·██▌▐▀ ▐█▀·.
 *  ▀  ▀ .▀    ▀  ▀  ▀▀▀ ▀▀▀ ·  ▀ •
 *  <https://fortreeforums.xyz/>
 */

namespace apathy\StyleSuite\NF\UserOnboarding\Condition;

use NF\UserOnboarding\Condition\AbstractCondition;
use NF\UserOnboarding\Entity\Task;
use XF\Job\AbstractJob;
use XF\Job\JobResult;
use XF\Mvc\Entity\Entity;

class Profile extends AbstractCondition
{
    public function getShortName()
    {
        return 'apathy\StyleSuite\NF\UserOnboarding:Profile';
    }

    public function getOptionLabel()
    {
        return \XF::phrase('ap_ss_has_pr_style');
    }

    public function getEventListeners()
    {
        return [
            [
                'entity_post_save',
                function (Entity $entity) {
                    if (!\XF::visitor()->user_id || $entity->user_id != \XF::visitor()->user_id)
                    {
                        return;
                    }

                    $this->matchConditions([]);
                },
                'apathy\StyleSuite\Entity\Profile'
            ]
        ];
    }

    public function isEnabled()
    {
        return isset(\XF::app()->container('addon.cache')['apathy/StyleSuite']);
    }

    public function getDisplayOrder()
    {
        return 1113;
    }

    public function processExistingMatches(AbstractJob $job, Task $task, array $handlerData, &$position, $maxRunTime)
    {
        $startTime = microtime(true);

        $userIds = $this->app->db()->fetchAllColumn("
            SELECT DISTINCT user_id
            FROM xf_ap_profile_styles
            WHERE user_id > ?
            AND pr_page_header != ''
            OR pr_navbar_bg != ''
            OR pr_page_bg != ''
            OR pr_font_color != ''
            OR pr_url_color != ''
            OR pr_highlight_color != ''
            OR pr_box_header != ''
            OR pr_box_bg != ''
            OR pr_border_color != ''
            OR pr_border_alt_color != ''
            OR pr_button != ''
            OR pr_css != ''
            ORDER BY user_id",
            [$position]
        );

        if (!$userIds)
        {
            return $job->complete();
        }

        foreach ($userIds AS $userId)
        {
            $position = $userId;

            $completionEntity = $this->app->em()->create('NF\UserOnboarding:TaskCompletion');
            $completionEntity->user_id = $userId;
            $completionEntity->onboarding_task_id = $task->onboarding_task_id;
            $completionEntity->useReplaceInto(true);
            $completionEntity->save();

            if ($maxRunTime && microtime(true) - $startTime >= $maxRunTime)
            {
                break;
            }
        }

        return $job->resume();
    }
}

