<?php

/**
 *  ▄▄▄·  ▄▄▄· ▄▄▄· ▄▄▄▄▄ ▄ .▄ ▄· ▄▌
 * ▐█ ▀█ ▐█ ▄█▐█ ▀█ •██  ██▪▐█▐█▪██▌
 * ▄█▀▀█  ██▀·▄█▀▀█  ▐█.▪██▀▐█▐█▌▐█▪
 * ▐█ ▪▐▌▐█▪·•▐█ ▪▐▌ ▐█▌·██▌▐▀ ▐█▀·.
 *  ▀  ▀ .▀    ▀  ▀  ▀▀▀ ▀▀▀ ·  ▀ •
 *  <https://fortreeforums.xyz/>
 */

namespace apathy\StyleSuite\NF\UserOnboarding\Condition;

use NF\UserOnboarding\Condition\AbstractCondition;
use NF\UserOnboarding\Entity\Task;
use XF\Job\AbstractJob;
use XF\Job\JobResult;
use XF\Mvc\Entity\Entity;

class Username extends AbstractCondition
{
    public function getShortName()
    {
        return 'apathy\StyleSuite\NF\UserOnboarding:Username';
    }

    public function getOptionLabel()
    {
        return \XF::phrase('ap_ss_has_uname_style');
    }

    public function getEventListeners()
    {
        return [
            [
                'entity_post_save',
                function (Entity $entity) {
                    if(\XF::visitor()->user_id != $entity->user_id)
                    {
                        return;
                    }

                    if($entity->isChanged('ap_username_style') && $entity->ap_username_style)
                    {
                        $this->matchConditions([]);
                    }
                },
                'XF\Entity\User'
            ]
        ];
    }

    public function isEnabled()
    {
        return isset(\XF::app()->container('addon.cache')['apathy/StyleSuite']);
    }

    public function getDisplayOrder()
    {
        return 1115;
    }

    public function processExistingMatches(AbstractJob $job, Task $task, array $handlerData, &$position, $maxRunTime)
    {
        $startTime = microtime(true);

        $userIds = $this->app->db()->fetchAllColumn("
            SELECT DISTINCT user_id
            FROM xf_user
            WHERE user_id > ?
            AND ap_username_style != NULL
            ORDER BY user_id",
            [$position]
        );

        if (!$userIds)
        {
            return $job->complete();
        }

        foreach ($userIds AS $userId)
        {
            $position = $userId;

            $completionEntity = $this->app->em()->create('NF\UserOnboarding:TaskCompletion');
            $completionEntity->user_id = $userId;
            $completionEntity->onboarding_task_id = $task->onboarding_task_id;
            $completionEntity->useReplaceInto(true);
            $completionEntity->save();

            if ($maxRunTime && microtime(true) - $startTime >= $maxRunTime)
            {
                break;
            }
        }

        return $job->resume();
    }
}

