<?php

/**
 *  ▄▄▄·  ▄▄▄· ▄▄▄· ▄▄▄▄▄ ▄ .▄ ▄· ▄▌
 * ▐█ ▀█ ▐█ ▄█▐█ ▀█ •██  ██▪▐█▐█▪██▌
 * ▄█▀▀█  ██▀·▄█▀▀█  ▐█.▪██▀▐█▐█▌▐█▪
 * ▐█ ▪▐▌▐█▪·•▐█ ▪▐▌ ▐█▌·██▌▐▀ ▐█▀·.
 *  ▀  ▀ .▀    ▀  ▀  ▀▀▀ ▀▀▀ ·  ▀ •
 *  <https://fortreeforums.xyz/>
 */

namespace apathy\StyleSuite\Pub\Controller;

use apathy\StyleSuite\Entity\Block as BlockEntity;
use XF;
use XF\Mvc\ParameterBag;
use XF\Mvc\Reply\View;
use XF\Pub\Controller\AbstractController;

class Block extends AbstractController
{
    protected function addAccountWrapperParams(View $view, $selected): View
    {
        $view->setParam('pageSelected', $selected);

        return $view;
    }

    public static function getActivityDetails(array $activities)
    {
        return XF::phrase('ap_ss_view_style_settings');
    }

    public function actionIndex(): View
    {
        $visitor = XF::visitor();

        if(!$visitor->canChangeProfileBlocks())
        {
            return $this->noPermission();
        }

        $viewParams = [
            'blocks' => $visitor->Block
        ];

        $view = $this->view('apathy\StyleSuite:Block', 'ap_ss_block_settings', $viewParams);

        return $this->addAccountWrapperParams($view, 'block-settings');
    }

    public function actionAddEdit(BlockEntity $block)
    {
        $visitor = XF::visitor();

        if(!$visitor->canChangeProfileBlocks())
        {
            return $this->noPermission();
        }

        if($this->isPost())
        {
            $this->blockSaveProcess($block)->run();

            return $this->redirect($this->buildLink('account/block-settings'));
        }

        /** @var \apathy\StyleSuite\Repository\Block $repo */
        $repo = $this->repository('apathy\StyleSuite:Block');

        $viewParams = [
            'blocks'          => $repo->fetchBlocks(),
            'block'           => $block,
            'disabledButtons' => $repo->getDisabledEditorButtons()
        ];

        $view = $this->view('apathy\StyleSuite:Block\Edit', 'ap_ss_block_edit', $viewParams);

        return $this->addAccountWrapperParams($view, 'block-settings');
    }

    public function actionAdd()
    {
        $blockId = $this->filter('block_id', 'int');

        if(!empty($blockId))
        {
            $block = $this->assertViewableBlock($blockId);
        }
        else
        {
            $block = $this->app()->em()->create('apathy\StyleSuite:Block');
        }

        return $this->actionAddEdit($block);
    }

    public function actionEdit(ParameterBag $params)
    {
        $block = $this->assertViewableBlock($params->block_id);

        return $this->actionAddEdit($block);
    }

    public function actionDelete(ParameterBag $params)
    {
        $block = $this->assertViewableBlock($params->block_id);

        $plugin = $this->plugin('XF:Delete');

        return $plugin->actionDelete(
            $block,
            $this->buildLink('account/block-settings/delete', $block),
            $this->buildLink('account/block-settings/edit', $block),
            $this->buildLink('account/block-settings'),
            $block->title
        );
    }

    public function actionToggle()
    {
        $plugin = $this->plugin('XF:Toggle');

        return $plugin->actionToggle('apathy\StyleSuite:Block');
    }

    protected function blockSaveProcess(BlockEntity $block)
    {
        $app = $this->app();
        $form = $this->formAction();

        $input = $this->filter([
            'title'        => 'str',
            'type'         => 'str',
            'content'      => 'str',
            'content_html' => 'str',
            'position'     => 'int'
        ]);

        if(!empty($input['content_html']))
        {
            $input['content'] = $input['content_html'];
        }

        unset($input['content_html']);

        $block->type = $input['type'];

        if($block->hasAutolinkProperty())
        {
            /** @todo
             * Check if bbCode is present instead of
             * running `isUpdate()`
             */
            if(!$block->isUpdate() && !$block->isValidId($input['content']))
            {
                $type = ucfirst($input['type']);

                throw new XF\PrintableException(XF::phrase(
                    'ap_ss_please_enter_valid_id', ['type' => $type]
                ));
            }

            /** @var \XF\Service\Message\Preparer $service */
            $service = $this->service('XF:Message\Preparer', 'profile_block', $block);
            $input['content'] = $service->prepare($input['content']);
        }
        else
        {
            $input['content'] = $this->plugin('XF:Editor')->fromInput('content');
        }

        $input['fa_icon'] = $block->getFontAwesomeIcon();

        $input['active'] = 1;

        $form->basicEntitySave($block, $input);

        return $form;
    }

    protected function assertViewableBlock($block_id, $with = NULL)
    {
        return $this->assertRecordExists('apathy\StyleSuite:Block', $block_id, $with, 'ap_ss_no_block_found');
    }
}
