<?php

/**
 *  ▄▄▄·  ▄▄▄· ▄▄▄· ▄▄▄▄▄ ▄ .▄ ▄· ▄▌
 * ▐█ ▀█ ▐█ ▄█▐█ ▀█ •██  ██▪▐█▐█▪██▌
 * ▄█▀▀█  ██▀·▄█▀▀█  ▐█.▪██▀▐█▐█▌▐█▪
 * ▐█ ▪▐▌▐█▪·•▐█ ▪▐▌ ▐█▌·██▌▐▀ ▐█▀·.
 *  ▀  ▀ .▀    ▀  ▀  ▀▀▀ ▀▀▀ ·  ▀ •
 *  <https://fortreeforums.xyz/>
 */

namespace apathy\StyleSuite\Pub\Controller;

use apathy\StyleSuite\Helper;
use XF;
use XF\Mvc\Reply\View;
use XF\Pub\Controller\AbstractController;

class Style extends AbstractController
{
    use Style\AvatarFrame;
    use Style\CustomTitle;
    use Style\Post;
    use Style\Postbit;
    use Style\Profile;
    use Style\Tooltip;
    use Style\Username;
    
    protected function addAccountWrapperParams(View $view, $selected): View
    {
        $view->setParam('pageSelected', $selected);

        return $view;
    }

    public static function getActivityDetails(array $activities)
    {
        return XF::phrase('ap_ss_view_style_settings');
    }

    public function actionIndex()
    {
        $visitor = XF::visitor();

        if(!$visitor->canChangeStyles())
        {
            return $this->noPermission();
        }

        $options = XF::options();

        /** @var \apathy\StyleSuite\Repository\Styles $repo */
        $repo  = $this->repository('apathy\StyleSuite:Styles');
        $fontCache = Helper::cleanUpFontNames($repo->getFontsFromCache());

        $sparkleCache = $repo->getSparklesFromCache();

        $postbitCache = [];

        if(!$options->ap_disable_postbit_styles)
        {
            $postbitCache = $repo->getPostbitPresetsFromCache();
            $postbitCache = $repo->sortItemsByAttribute($postbitCache);
        }

        $frameCache = [];

        if(!$options->ap_disable_frame_styles)
        {
            $frameCache = $repo->getFramesFromCache();
            $frameCache = $repo->sortItemsByAttribute($frameCache);
        }
        
        $viewParams = [
            'fontCache'    => $fontCache,
            'postbitCache' => $postbitCache,
            'sparkleCache' => $sparkleCache,
            'frameCache'   => $frameCache,
            'dataDir'      => $this->app()->applyExternalDataUrl('apathy/StyleSuite', false)
        ];

        if($this->isPost())
        {
            if($this->filter('frameStyle', 'bool'))
            {
                $this->avatarFrameSave($visitor);
                $link = 'account/style-settings#frame';
            }
            elseif($this->filter('custom_title', 'bool'))
            {
                $this->customTitleStyleSave($visitor)->run();
                $link = 'account/style-settings#custom-title';
            }
            elseif($this->filter('postbit', 'bool'))
            {
                $this->postbitStyleSave($visitor)->run();
                $link = 'account/style-settings#postbit';
            }
            elseif($this->filter('post', 'bool'))
            {
                $this->postStyleSave($visitor)->run();
                $link = 'account/style-settings#post';
            }
            elseif($this->filter('profile', 'bool'))
            {
                $this->profileStyleSave($visitor)->run();
                $link = 'account/style-settings#profile';
            }
            elseif($this->filter('tooltip', 'bool'))
            {
                $this->tooltipStyleSave($visitor)->run();
                $repo->rebuildTooltipStyleCache();
                $link = 'account/style-settings#tooltip';
            }
            elseif($this->filter('username', 'bool'))
            {
                $this->usernameStyleSave($visitor)->run();
                $link = 'account/style-settings#username';
            }

            return $this->redirect($this->buildLink($link));
        }
        
        $view = $this->view('apathy\StyleSuite:Styles', 'ap_ss_style_settings_wrapper', $viewParams);

        return $this->addAccountWrapperParams($view, 'style-settings');
    }
}
