<?php

/**
 *  ▄▄▄·  ▄▄▄· ▄▄▄· ▄▄▄▄▄ ▄ .▄ ▄· ▄▌
 * ▐█ ▀█ ▐█ ▄█▐█ ▀█ •██  ██▪▐█▐█▪██▌
 * ▄█▀▀█  ██▀·▄█▀▀█  ▐█.▪██▀▐█▐█▌▐█▪
 * ▐█ ▪▐▌▐█▪·•▐█ ▪▐▌ ▐█▌·██▌▐▀ ▐█▀·.
 *  ▀  ▀ .▀    ▀  ▀  ▀▀▀ ▀▀▀ ·  ▀ •
 *  <https://fortreeforums.xyz/>
 */

namespace apathy\StyleSuite\Pub\Controller\Style;

use apathy\StyleSuite\Helper;
use XF;
use XF\Entity\User;

trait Postbit
{
    protected function postbitStyleSave(User $visitor)
    {
        if(!$visitor->canChangePostbitStyle())
        {
            return $this->noPermission();
        }

        $app = $this->app();
        $form = $this->formAction();
        $options = XF::options();

        /** @var \apathy\StyleSuite\Repository\Styles $repo */
        $repo = $this->repository('apathy\StyleSuite:Styles');

        $input = $this->filter([
            'disable'       => 'bool',
            'background'    => 'str',
            'bg_type'       => 'uint',
            'bg_repeat'     => 'str',
            'bg_position'   => 'array',
            'bg_size'       => 'str',
            'bg_opacity'    => 'uint',
            'bg_brightness' => 'float',
            'bg_contrast'   => 'uint',
            'bg_blur'       => 'uint',
            'color'         => 'str',
            'text_shadow'   => 'bool',
            'css'           => 'str'
        ]);
        
        if(!empty($input['bg_position']))
        {
            $input['bg_position'] = implode(',', $input['bg_position']);
        }

        $entity = $app->em()->findOne('apathy\StyleSuite:Postbit', [
            'user_id' => $visitor->user_id
        ]);

        if(!$entity)
        {
            $entity = $app->em()->create('apathy\StyleSuite:Postbit');
            $entity->user_id = $visitor->user_id;
        }

        switch($input['bg_type'])
        {
            case 0: /** Image URL */
                if(Helper::verifyUrl($input['background'])
                && strpos($options->boardUrl, $input['background']) === false)
                {
                    Helper::proxyImage($input['background']);
                }
            break;
            case 1: /** Upload */
                /** @var \apathy\StyleSuite\Service\User\Postbit $service */
                $service = $this->app()->service(
                    'apathy\StyleSuite:User\Postbit', $visitor, $entity
                );

                $upload = $this->request->getFile('pbit_bg_upload', false);

                $input['background'] = $repo->uploadPostbitImage($service, $entity, $upload);
            break;
            case 2: /** Preset */
                $input['background'] = $this->filter('pbit_bg_preset', 'str');
            break;
        }

        if(!empty($input['color']))
        {
            Helper::verifyColors([$input['color']]);
        }

        if(!empty($input['css']))
        {
            Helper::verifyCss($input['css']);
        }

        $form->basicEntitySave($entity, $input);

        return $form;
    }
}
 
