<?php

/**
 *  ▄▄▄·  ▄▄▄· ▄▄▄· ▄▄▄▄▄ ▄ .▄ ▄· ▄▌
 * ▐█ ▀█ ▐█ ▄█▐█ ▀█ •██  ██▪▐█▐█▪██▌
 * ▄█▀▀█  ██▀·▄█▀▀█  ▐█.▪██▀▐█▐█▌▐█▪
 * ▐█ ▪▐▌▐█▪·•▐█ ▪▐▌ ▐█▌·██▌▐▀ ▐█▀·.
 *  ▀  ▀ .▀    ▀  ▀  ▀▀▀ ▀▀▀ ·  ▀ •
 *  <https://fortreeforums.xyz/>
 */

namespace apathy\StyleSuite\Pub\Controller\Style;

use apathy\StyleSuite\Helper;
use XF\Entity\User;

trait Profile
{
    protected function profileStyleSave(User $visitor)
    {
        if(!$visitor->canChangeProfileStyle())
        {
            return $this->noPermission();
        }

        $form = $this->formAction();

        $input = $this->filter([
            'pr_page_header'      => 'str',
            'pr_navbar_bg'        => 'str',
            'pr_page_bg'          => 'str',
            'pr_page_bg_type'     => 'int',
            'pr_page_bg_rep'      => 'int',
            'pr_font_color'       => 'str',
            'pr_url_color'        => 'str',
            'pr_highlight_color'  => 'str',
            'pr_box_header'       => 'str',
            'pr_box_bg'           => 'str',
            'pr_border_color'     => 'str',
            'pr_border_alt_color' => 'str',
            'pr_button'           => 'str',
            'pr_scrollbar_color'  => 'str',
            'pr_scrollbar_width'  => 'int',
            'pr_scrollbar_bg'     => 'str',
            'pr_scrollbar_radius' => 'int',
            'pr_css'              => 'str'
        ]);

        if(!empty($input['pr_page_header']))
        {
            Helper::verifyUrl($input['pr_page_header']);
        }

        $colors = [
            $input['pr_navbar_bg'],
            $input['pr_font_color'],
            $input['pr_url_color'],
            $input['pr_highlight_color'],
            $input['pr_box_header'],
            $input['pr_box_bg'],
            $input['pr_border_color'],
            $input['pr_border_alt_color'],
            $input['pr_button'],
            $input['pr_scrollbar_color'],
            $input['pr_scrollbar_bg']
        ];

        if($input['pr_page_bg_type'] == 0) // Solid color
        {
            $colors[] = $input['pr_page_bg'];
        }
        else
        {
            Helper::verifyUrl($input['pr_page_bg']);
        }

        if(!empty($colors))
        {
            Helper::verifyColors($colors);
        }

        if(!empty($input['pr_css']))
        {
            Helper::verifyCss($input['pr_css']);
        }

        $entity = $this->em()->findOne('apathy\StyleSuite:Profile', [
            'user_id' => $visitor->user_id
        ]);

        if(!$entity)
        {
            $input['user_id'] = $visitor->user_id;

            $entity = $this->em()->create('apathy\StyleSuite:Profile');
        }

        $form->basicEntitySave($entity, $input);

        return $form;
    }
}
 
