<?php

/**
 *  ▄▄▄·  ▄▄▄· ▄▄▄· ▄▄▄▄▄ ▄ .▄ ▄· ▄▌
 * ▐█ ▀█ ▐█ ▄█▐█ ▀█ •██  ██▪▐█▐█▪██▌
 * ▄█▀▀█  ██▀·▄█▀▀█  ▐█.▪██▀▐█▐█▌▐█▪
 * ▐█ ▪▐▌▐█▪·•▐█ ▪▐▌ ▐█▌·██▌▐▀ ▐█▀·.
 *  ▀  ▀ .▀    ▀  ▀  ▀▀▀ ▀▀▀ ·  ▀ •
 *  <https://fortreeforums.xyz/>
 */

namespace apathy\StyleSuite\Repository;

use apathy\StyleSuite\Block\AbstractBlock;
use XF\Mvc\Entity\ArrayCollection;
use XF\Mvc\Entity\Repository;

class Block extends Repository
{
    public function getDisabledEditorButtons()
    {
        return [
            '_media'
        ];
    }

    public function getHandler(string $type)
    {
        $app = $this->app();
        $type = trim($type) . '_profile_block';

        $class = $app->getContentTypeFieldValue($type, 'ap_ss_block_handler_class');

        if(class_exists($class))
        {
            $class = $app->extendClass($class);

            return new $class($app);
        }
    }

    public function getHandlers(): array
    {
        $app = $this->app();
        $types = $app->getContentTypeField('ap_ss_block_handler_class');

        $output = [];

        foreach($types as $type => $class)
        {
            if(class_exists($class))
            {
                $class = $app->extendClass($class);
                $output[$type] = new $class($app);
            }
        }

        return $output;
    }

    public function fetchBlocks(): ArrayCollection
    {
        $blocks = $this->getHandlers();

        if(empty($blocks))
        {
            return [];
        }

        foreach($blocks as $block)
        {
            $params = $block->getParams();

            if($block->isEnabled())
            {
                $output[$block->getType()] = $params;
            }
        }

        return new ArrayCollection($output);
    }
}
