<?php

/**
 *  ▄▄▄·  ▄▄▄· ▄▄▄· ▄▄▄▄▄ ▄ .▄ ▄· ▄▌
 * ▐█ ▀█ ▐█ ▄█▐█ ▀█ •██  ██▪▐█▐█▪██▌
 * ▄█▀▀█  ██▀·▄█▀▀█  ▐█.▪██▀▐█▐█▌▐█▪
 * ▐█ ▪▐▌▐█▪·•▐█ ▪▐▌ ▐█▌·██▌▐▀ ▐█▀·.
 *  ▀  ▀ .▀    ▀  ▀  ▀▀▀ ▀▀▀ ·  ▀ •
 *  <https://fortreeforums.xyz/>
 */

namespace apathy\StyleSuite;

use XF\AddOn\AbstractSetup;
use XF\AddOn\StepRunnerInstallTrait;
use XF\AddOn\StepRunnerUninstallTrait;
use XF\AddOn\StepRunnerUpgradeTrait;

class Setup extends AbstractSetup
{
    use StepRunnerInstallTrait;
    use StepRunnerUpgradeTrait;
    use StepRunnerUninstallTrait;

    use Install\PostUpgrade;
    use Install\Registry;
    use Install\Table;

    /**
     * Upgrades
     */
    use Install\Upgrade1030070;
    use Install\Upgrade1050070;
    use Install\Upgrade1060070;
    use Install\Upgrade2010270;
    use Install\Upgrade2020170;
    use Install\Upgrade2070070;
    use Install\Upgrade2080070;
    use Install\Upgrade2080170;
    use Install\Upgrade2090070;
    use Install\Upgrade2090570;
    use Install\Upgrade2090670;

    public function installStep1()
    {
        $schemaManager = $this->schemaManager();
        $tables = $this->getTables();

        foreach($tables as $name => $data)
        {
            $schemaManager->createTable($name, $data);
        }
    }

    public function uninstallStep1()
    {
        $schemaManager = $this->schemaManager();
        $tableNames = array_keys($this->getTables());

        foreach($tableNames as $name)
        {
            $schemaManager->dropTable($name);
        }

        /**
         * Delete registry keys
         */
        $registry = $this->app->registry();
        $registryKeys = $this->getRegistryKeys();

        foreach($registryKeys as $key)
        {
            $registry->delete($key);
        }
    }

    public function installStep2()
    {
        $schemaManager = $this->schemaManager();
        $tables = $this->getAlteredTables();

        foreach($tables as $name => $definition)
        {
            if($schemaManager->tableExists($name))
            {
                $schemaManager->alterTable($name, $definition);
            }
        }
    }

    public function uninstallStep2()
    {
        $schemaManager = $this->schemaManager();
        $tables = $this->dropAlteredTableColumns();

        foreach($tables as $name => $definition)
        {
            $schemaManager->alterTable($name, $definition);
        }
    }

    public function postInstall(array &$stateChanges)
    {
        $this->rebuildCaches();
    }

    public function postUpgrade($previousVersion, array &$stateChanges)
    {
        $postUpgradeMethods = $this->getPostUpgradeMethods();

        foreach($postUpgradeMethods as $postUpgradeMethod)
        {
            $version = strtr($postUpgradeMethod, ['postUpgrade', '']);

            if(!$previousVersion || $previousVersion >= $version)
            {
                continue;
            }

            $this->$postUpgradeMethod($previousVersion, $stateChanges);
        }

        $this->rebuildCaches();
    }

    protected function rebuildCaches()
    {
        /** @var \apathy\StyleSuite\Repository\Styles $repo */
        $repo = $this->app->repository('apathy\StyleSuite:Styles');

        $repo->rebuildUsernameStyleCache();
        $repo->rebuildUsernameGlowCache();

        $repo->rebuildCustomTitleStyleCache();
        $repo->rebuildCustomTitleGlowCache();
        $repo->rebuildTooltipStyleCache();
        $repo->rebuildPostbitPresetCache();
        $repo->rebuildFontCache();
        $repo->rebuildFrameCache();
        $repo->rebuildSparkleCache();
    }
}
