<?php

/**
 *  ▄▄▄·  ▄▄▄· ▄▄▄· ▄▄▄▄▄ ▄ .▄ ▄· ▄▌
 * ▐█ ▀█ ▐█ ▄█▐█ ▀█ •██  ██▪▐█▐█▪██▌
 * ▄█▀▀█  ██▀·▄█▀▀█  ▐█.▪██▀▐█▐█▌▐█▪
 * ▐█ ▪▐▌▐█▪·•▐█ ▪▐▌ ▐█▌·██▌▐▀ ▐█▀·.
 *  ▀  ▀ .▀    ▀  ▀  ▀▀▀ ▀▀▀ ·  ▀ •
 *  <https://fortreeforums.xyz/>
 */

namespace apathy\StyleSuite\Template\Style;

use XF;
use XF\Entity\User;

trait Post
{
    /**
     * This function injects the post style, which affects the
     * actual message content.
     */
    public static function fnPostStyle($templater, &$escape, $post): string
    {
        $escape = false;
        $visitor = XF::visitor();

        $user  = $post->User;
        $style = $user->ap_post_style ?? NULL;

        if(!$user instanceof User || empty($style) || !$visitor->canViewPostStyle($user))
        {
            return '';
        }

        $attributes['style'] = '';

        if($style['post_bold'])
        {
            $attributes['style'] .= 'font-weight:bold;';
        }

        if($style['post_italic'])
        {
            $attributes['style'] .= 'font-style:italic;';
        }

        if($style['post_underline'])
        {
            $attributes['style'] .= 'text-decoration:underline;';
        }

        if($style['post_color'])
        {
            $attributes['style'] .= 'color:' . htmlspecialchars($style['post_color']) . ';';
        }

        if($style['post_font'])
        {
            $attributes['style'] .= 'font-family:'.htmlspecialchars($style['post_font']).';';
        }

        if($style['post_font_size'])
        {
            $attributes['style'] .= 'font-size:'.htmlspecialchars($style['post_font_size']).'px;';
        }

        return $templater->processAttributeToRaw($attributes, 'style', ' %s', true);
    }
}
 
