<?php

/**
 *  ▄▄▄·  ▄▄▄· ▄▄▄· ▄▄▄▄▄ ▄ .▄ ▄· ▄▌
 * ▐█ ▀█ ▐█ ▄█▐█ ▀█ •██  ██▪▐█▐█▪██▌
 * ▄█▀▀█  ██▀·▄█▀▀█  ▐█.▪██▀▐█▐█▌▐█▪
 * ▐█ ▪▐▌▐█▪·•▐█ ▪▐▌ ▐█▌·██▌▐▀ ▐█▀·.
 *  ▀  ▀ .▀    ▀  ▀  ▀▀▀ ▀▀▀ ·  ▀ •
 *  <https://fortreeforums.xyz/>
 */

namespace apathy\StyleSuite\Template\Style;

use XF;
use XF\Entity\User;

trait Postbit
{
    public static function fnPostbitFilters($templater, &$escape, $user)
    {
        if($user === NULL)
        {
            return '';
        }

        $visitor = XF::visitor();

        $escape = false;

        $style = $user->postbit_style;

        if(!$user instanceof User || !$user->hasPostbitStyle() 
        || empty($style) || !$visitor->canViewPostbitStyle($user))
        {
            return '';
        }

        $attributes['style'] = '';

        $brightness = ' brightness(' . floatval($style['bg_brightness']) . ') ';
        $opacity    = ' opacity('    . intval($style['bg_opacity'])      . '%) ';
        $contrast   = ' contrast('   . intval($style['bg_contrast'])     . '%) ';
        $blur       = ' blur('       . intval($style['bg_blur'])         . 'px) ';

        $attributes['style'] .= 'backdrop-filter:' . $brightness . $opacity . $contrast . $blur . ';';

        return $templater->processAttributeToRaw($attributes, 'style', ' %s', true);
    }

    /**
     * This function injects the postbit background, whereas
     * things like postbit text color/shadow are handled with 
     * template modifications.
     */
    public static function fnPostbitStyle($templater, &$escape, $user)
    {
        if($user === NULL)
        {
            return '';
        }
        
        $options = XF::options();
        $visitor = XF::visitor();

        $escape = false;

        $style = $user->postbit_style;

        if(!$user instanceof User || !$user->hasPostbitStyle() 
        || empty($style) || !$visitor->canViewPostbitStyle($user))
        {
            return '';
        }

        $app = XF::app();
        $dataDir = self::getPostbitDataUrl($style['bg_type']);

        $url = $dataDir . htmlspecialchars($style['background']);

        /** URL */
        if($style['bg_type'] === 0)
        {
            if($options->imageLinkProxy['images'] == 1
            && strpos($options->boardUrl, $style['background']) === false)
            {
                $style['background'] = $app->proxy()->generate('image', $style['background']);
            }
        }
        /** Upload */
        elseif($style['bg_type'] === 1 && $style['bg_date'])
        {
            $url = htmlspecialchars($style['background']);
        }

        $theme = $app->style($visitor->style_id);

        $topGrad = $theme->getProperty('apSsPbitGradStart');
        $botGrad = $theme->getProperty('apSsPbitGradEnd');
        $gradDir = $theme->getProperty('apSsPbitGradDir');

        $bgPosition = self::getBgImagePosition($style['bg_position']);
        $bgRepeat = self::getBgImageRepeat($style['bg_repeat']);

        $props = [
            'background' => [
                "background-image:linear-gradient({$gradDir}, {$topGrad}, {$botGrad}), url({$url});"
            ],
            'bg_position' => [
                'background-position:' . $bgPosition . ';'
            ],
            'bg_size' => [
                'background-size:' . htmlspecialchars($style['bg_size']) . ';'
            ],
            'bg_repeat' => [
                'background-repeat:' . $bgRepeat . ';'
            ],
            'css' => [
                htmlspecialchars($style['css'])
            ]
        ];

        $attributes['style'] = '';

        foreach($props as $prop => $value)
        {
            /**
             * @todo
             * Remove the $bg_repeat check once we've converted
             * the column to an integer
             * 
             * The final check should be 
             * `!empty($style[$prop] && $style[$prop] !== NULL)`
             */
            if($prop == 'bg_repeat' && $style[$prop] == '0'
            || !empty($style[$prop] && $style[$prop] !== NULL))
            {
                $attributes['style'] .= $value[0];
            }
        }

        return $templater->processAttributeToRaw($attributes, 'style', ' %s', true);
    }

    protected static function getBgImagePosition($position): string
    {
        if(empty($position))
        {
            return '50%';
        }

        $positions = explode(',', $position);

        $bgPosition = $positions[0] . '%';

        if(isset($positions[1]))
        {
            $bgPosition .= ' ' . $positions[1] . '%';
        }

        return $bgPosition;
    }

    protected static function getBgImageRepeat($repeat): string
    {
        $repeat = intval($repeat);

        switch($repeat)
        {
            case 0:
                return 'no-repeat';
            case 1:
                return 'repeat-x';
            case 2:
                return 'repeat-y';
            case 3:
                return 'repeat';
        }
    }

    protected static function getPostbitDataUrl(int $bgType, bool $canonical = false): string
    {
        $app = XF::app();
        $dataPath = $app->applyExternalDataUrl('apathy/StyleSuite', $canonical);

        switch($bgType)
        {
            case 0: // URL images
                return '';
            case 1: // Uploaded images
                return $dataPath . '/postbits/';
            case 2: // Preset images
                return $dataPath . '/postbits/presets/';
        }
    }
}
 
