<?php

/**
 *  ▄▄▄·  ▄▄▄· ▄▄▄· ▄▄▄▄▄ ▄ .▄ ▄· ▄▌
 * ▐█ ▀█ ▐█ ▄█▐█ ▀█ •██  ██▪▐█▐█▪██▌
 * ▄█▀▀█  ██▀·▄█▀▀█  ▐█.▪██▀▐█▐█▌▐█▪
 * ▐█ ▪▐▌▐█▪·•▐█ ▪▐▌ ▐█▌·██▌▐▀ ▐█▀·.
 *  ▀  ▀ .▀    ▀  ▀  ▀▀▀ ▀▀▀ ·  ▀ •
 *  <https://fortreeforums.xyz/>
 */

namespace apathy\StyleSuite\Template\Style;

use XF;
use XF\Entity\User;

trait Username
{
    public static function fnUsernameIcon($templater, &$escape, $user, $groupStyle = NULL, 
    $attributes = []): string
    {
        $escape = false;
        $options = XF::options();
        $visitor = XF::visitor();

        $style = $user->username_style;

        if(!$user instanceof User
        || empty($style['icon'])
        || !$visitor->canViewUsernameStyle($user))
        {
            return '';
        }

        $icon = htmlspecialchars($style['icon']);
        $pos  = $style['icon_position'] == 1 ? 'right' : 'left';
        
        if($style['icon_type'] == 0)
        {
            $type = 'fa';
        }
        else
        {
            $type = 'img';
        }

        $attributes['class'] = 'ap-ss-usernameIcon';
        $attributes['class'] .= ' ap-ss-usernameIcon-' . intval($user->user_id) . '--' . $pos;
        $attributes['class'] .= ' ap-ss-usernameIcon--' . htmlspecialchars($type);
        
        $class = $templater->processAttributeToRaw($attributes, 'class', ' %s', true);

        if($options->ap_uname_icon_styling == 'separate')
        {
            $color = $style['icon_color'];
            $color = htmlspecialchars($color);

            /** @todo Add options */
            $glow      = NULL;
            $bg        = NULL;
            $italic    = NULL;
            $underline = NULL;
        }
        else
        {
            $color     = htmlspecialchars($style['color']);
            $glow      = htmlspecialchars($style['glow']);
            $glow_str  = $style['glow_strength'];
            $bg        = htmlspecialchars($style['inner_text_animation']);
            $italic    = $style['italic'];
            $underline = $style['underline'];
        }

        if($style['icon_type'] == 0)
        {
            if(empty($color))
            {
                $css = $groupStyle;
                $attributes['style'] .= $css;
            }
            
            if($user->hasPermission('ap_styles', 'ap_change_un_color') && !empty($color))
            {
                $attributes['style'] .= 'color:' . $color . ';';
            }

            if($user->hasPermission('ap_styles', 'ap_change_un_glow') && !empty($glow) && $glow_str)
            {
                $attributes['style'] .= 'text-shadow: 0 0 2px '.$glow.', 0 0 4px '.$glow.', 0 0 6px '.$glow.', 0 0 8px '.$glow.', 0 0 10px '.$glow.';';
            }

            if($user->hasPermission('ap_styles', 'ap_change_un_bg') && !empty($bg))
            {
                $attributes['id'] = 'ap-text-bg';
                $attributes['style'] .= 'background-image:url(' . $bg . ');';
            }

            if($user->hasPermission('ap_styles', 'ap_change_un_italic') && !empty($italic))
            {
                $attributes['style'] .= 'font-style:italic;';
            }

            if($user->hasPermission('ap_styles', 'ap_change_un_underline') && !empty($underline))
            {
                $attributes['style'] .= 'text-decoration:underline;';
            }

            $id    = $templater->processAttributeToRaw($attributes, 'id', ' %s', true);
            $style = $templater->processAttributeToRaw($attributes, 'style', ' %s', true);

            return "<i class=\"{$icon} {$class}\" id=\"{$id}\" style=\"{$style}\"></i>";
        }
        
        $path = $style['icon'];

        if($path === NULL)
        {
            $path = $style->getIconDataUrl() . $style['icon'];
        }

        $attributes['height'] = $options->apSsMaxIconHeight.'px';
        $attributes['width']  = $options->apSsMaxIconWidth.'px';

        $uname = htmlspecialchars($user->username);

        $height = $templater->processAttributeToRaw($attributes, 'height', ' %s', true);
        $width  = $templater->processAttributeToRaw($attributes, 'width', ' %s', true);

        return "<img class=\"{$class}\" src=\"{$path}\" loading=\"lazy\" alt=\"{$uname}'s icon\"
                     height=\"{$height}\" width=\"{$width}\" />";
    }
}
 
