<?php

/**
 *  ▄▄▄·  ▄▄▄· ▄▄▄· ▄▄▄▄▄ ▄ .▄ ▄· ▄▌
 * ▐█ ▀█ ▐█ ▄█▐█ ▀█ •██  ██▪▐█▐█▪██▌
 * ▄█▀▀█  ██▀·▄█▀▀█  ▐█.▪██▀▐█▐█▌▐█▪
 * ▐█ ▪▐▌▐█▪·•▐█ ▪▐▌ ▐█▌·██▌▐▀ ▐█▀·.
 *  ▀  ▀ .▀    ▀  ▀  ▀▀▀ ▀▀▀ ·  ▀ •
 *  <https://fortreeforums.xyz/>
 */

namespace apathy\StyleSuite\XF\Admin\Controller;

use XF;

/**
 * Don't import XF\Entity\User
 * or we get "Cannot redeclare class" errors
 */
class User extends XFCP_User
{
    protected function userAddEdit(\XF\Entity\User $user)
    {
        $parent = parent::userAddEdit($user);

        if(!XF::options()->ap_disable_frame_styles)
        {
            /** @var apathy\StyleSuite\XF\Repository\Styles $repo */
            $repo = $this->repository('apathy\StyleSuite:Styles');
            
            $frameCache = $repo->getFramesFromCache();
            $frameCache = $repo->sortItemsByAttribute($frameCache);

            $parent->setParams([
                'frameCache' => $frameCache
            ]);
        }

        return $parent;
    }

    protected function userSaveProcess(\XF\Entity\User $user)
    {
        $frame = $this->filter('frame', 'str');

        /** We cant fastUpdate if the account hasnt been created */
        if($user->user_id == 0)
        {
            return parent::userSaveProcess($user);
        }

        $user->fastUpdate('ap_frame', $frame);

        return parent::userSaveProcess($user);
    }
}
