<?php

/**
 *  ▄▄▄·  ▄▄▄· ▄▄▄· ▄▄▄▄▄ ▄ .▄ ▄· ▄▌
 * ▐█ ▀█ ▐█ ▄█▐█ ▀█ •██  ██▪▐█▐█▪██▌
 * ▄█▀▀█  ██▀·▄█▀▀█  ▐█.▪██▀▐█▐█▌▐█▪
 * ▐█ ▪▐▌▐█▪·•▐█ ▪▐▌ ▐█▌·██▌▐▀ ▐█▀·.
 *  ▀  ▀ .▀    ▀  ▀  ▀▀▀ ▀▀▀ ·  ▀ •
 *  <https://fortreeforums.xyz/>
 */

namespace apathy\StyleSuite\XF\Entity;

use XF;

class User extends XFCP_User
{
    public function canViewAvatarFrame(User $user): bool
    {
        if($user->canChangeAvatarFrame() && !$this->hasUserStylesDisabled()
        && !$this->isIgnoringStyle($user))
        {
            return true;
        }

        return false;
    }

    public function canViewCustomTitleStyle(User $user): bool
    {
        if($user->canChangeUsernameStyle() && !$this->hasUserStylesDisabled()
        && !$this->isIgnoringStyle($user))
        {
            return true;
        }

        return false;
    }

    public function canViewPostStyle(User $user): bool
    {
        if($user->canChangePostStyle() && !$this->hasPostStylesDisabled()
        && !$this->hasUserStylesDisabled() && !$this->isIgnoringStyle($user))
        {
            return true;
        }

        return false;
    }

    public function canViewPostbitStyle(User $user): bool
    {
        if($user->canChangePostbitStyle()  && !$this->hasPostbitsDisabled() 
        && !$this->hasUserStylesDisabled() && !$this->isIgnoringStyle($user))
        {
            return true;
        }

        return false;
    }

    public function canViewUsernameStyle(User $user): bool
    {
        if($user->canChangeUsernameStyle() && !$this->hasUserStylesDisabled()
        && !$this->isIgnoringStyle($user))
        {
            return true;
        }

        return false;
    }

    public function canChangeProfileBlocks()
    {
        return $this->hasPermission('ap_styles', 'ap_ss_change_blocks');
    }

    public function canChangeStyles()
    {
        return $this->hasPermission('ap_styles', 'ap_ss_change_styles');
    }

    public function canChangeAvatarFrame()
    {
        if(XF::options()->ap_disable_frame_styles)
        {
            return false;
        }

        return $this->hasPermission('ap_styles', 'ap_change_frame');
    }

    public function canChangeCustomTitleStyle()
    {
        if(XF::options()->ap_disable_title_styles)
        {
            return false;
        }

        return $this->hasPermission('ap_styles', 'ap_change_ttl_style');
    }

    public function canChangePostStyle()
    {
        if(XF::options()->ap_disable_post_styles)
        {
            return false;
        }

        return $this->hasPermission('ap_styles', 'ap_ss_change_post_style');
    }

    public function canChangePostbitStyle()
    {
        if(XF::options()->ap_disable_postbit_styles)
        {
            return false;
        }

        return $this->hasPermission('ap_styles', 'ap_change_pb_style');
    }

    public function canChangeProfileStyle()
    {
        if(XF::options()->ap_disable_profile_styles)
        {
            return false;
        }

        return $this->hasPermission('ap_styles', 'ap_change_pr_style');
    }

    public function canChangeTooltipStyle()
    {
        if(XF::options()->ap_disable_tooltip_styles)
        {
            return false;
        }

        return $this->hasPermission('ap_styles', 'ap_change_ttip_style');
    }

    public function canChangeUsernameStyle()
    {
        if(XF::options()->ap_disable_uname_styles)
        {
            return false;
        }

        return $this->hasPermission('ap_styles', 'ap_change_un_style');
    }

    public function findIgnoredUserStyles()
    {
        return implode(',', $this->UserStyleIgnored->pluckNamed('ignored_user_id'));
    }

    public function getPostbitStyle()
    {
        return $this->getStyleFromCache('apPostbits');
    }

    public function getUsernameStyle()
    {
        return $this->getStyleFromCache('apUnameStyles');
    }

    public function hasPostbitStyle(): bool
    {
        $style = $this->postbit_style;

        if($style === NULL || empty($style))
        {
            return false;
        }

        return true;
    }

    public function hasUsernameStyle(): bool
    {
        $style = $this->username_style;

        if($style === NULL || empty($style))
        {
            return false;
        }

        return true;
    }

    public function hasPostbitsDisabled(): bool
    {
        if(isset($this->postbit_style['disable'])
        && $this->postbit_style['disable'])
        {
            return true;
        }

        return false;
    }

    public function hasPostStylesDisabled(): bool
    {
        if(isset($this->ap_post_style['post_disable'])
        && $this->ap_post_style['post_disable'])
        {
            return true;
        }

        return false;
    }

    public function hasUserStylesDisabled(): bool
    {
        if($this->Option->ap_ss_disable_user_styles)
        {
            return true;
        }

        return false;
    }

    public function isIgnoringStyle(User $user): bool
    {
        if(in_array($user->user_id, $this->UserStyleIgnored->pluckNamed('ignored_user_id')))
        {
            return true;
        }

        return false;
    }

    protected function getStyleFromCache(string $cacheId): array
    {
        $cache = XF::registry()->get($cacheId);

        if(isset($cache[$this->user_id]))
        {
            return $cache[$this->user_id];
        }

        return [];
    }
}
