<?php

/**
 *  ▄▄▄·  ▄▄▄· ▄▄▄· ▄▄▄▄▄ ▄ .▄ ▄· ▄▌
 * ▐█ ▀█ ▐█ ▄█▐█ ▀█ •██  ██▪▐█▐█▪██▌
 * ▄█▀▀█  ██▀·▄█▀▀█  ▐█.▪██▀▐█▐█▌▐█▪
 * ▐█ ▪▐▌▐█▪·•▐█ ▪▐▌ ▐█▌·██▌▐▀ ▐█▀·.
 *  ▀  ▀ .▀    ▀  ▀  ▀▀▀ ▀▀▀ ·  ▀ •
 *  <https://fortreeforums.xyz/>
 */

namespace apathy\StyleSuite\XF\Template;

use XF;
use XF\Entity\User;

class Templater extends XFCP_Templater
{
    public function fnUsernameLink($templater, &$escape, $user, $rich = false, $attributes = [])
    {
        $style = $user->username_style ?? [];
        $visitor = XF::visitor();

        if(!$user instanceof User 
        || empty($style)
        || !$visitor->canViewUsernameStyle($user))
        {
            return parent::fnUsernameLink($templater, $escape, $user, $rich, $attributes);
        }
            
        $groupStyle = $this->groupStyles[$user->display_style_group_id]['username_css'];
        
        $icon = $templater->functions['usernameicon'](
            $templater, $escape, $user, $groupStyle, $attributes
        );

        $username = parent::fnUsernameLink($templater, $escape, $user, $rich, $attributes);
        $innerAnim  = $style['inner_text_animation'];

        if(!empty($innerAnim))
        {
            $attributes['style'] = 'background-image:url('.htmlspecialchars($innerAnim).')';
            $styleAttr = $this->processAttributeToRaw($attributes, 'style', ' %s', true);

            $username = "<span class=\"ap-ss-innerTextAnimation\" id=\"ap-text-bg\" style=\"{$styleAttr}\">{$username}</span>";
        }

        if(!empty($style['sparkle']))
        {
            $username = "<span class=\"ap-ss-sparkleStyle ap-sparkle-{$style['sparkle']}\">{$username}</span>";
        }

        if(isset($icon))
        {
            return ( $style['icon_position'] == 1 ) ? $username . $icon : $icon . $username;
        }

        return $username;
    }

    public function fnUsernameClasses($templater, &$escape, $user, $includeGroupStyling = true)
    {
        $classes = parent::fnUsernameClasses($templater, $escape, $user, $includeGroupStyling);

        $style   = $user->username_style ?? [];
        $visitor = XF::visitor();

        if(!$user instanceof User
        || empty($style)
        || !$visitor->canViewUsernameStyle($user))
        {
            return parent::fnUsernameClasses($templater, $escape, $user, $includeGroupStyling);
        }

        $classes .= ' ap-ss-usernameStyle ap-ss-usernameStyle--' . $user->user_id;

        return $classes;
    }

    public function fnUserTitle($templater, &$escape, $user, $withBanner = false, 
    $attributes = [])
    {
        $style   = $user->ap_title_style ?? NULL;
        $visitor = XF::visitor();

        if(!$user instanceof User
        || empty($style)
        || !$visitor->canViewUsernameStyle($user))
        {
            return parent::fnUserTitle($templater, $escape, $user, $withBanner, $attributes);
        }
            
        $sparkle   = $style['ttl_sparkle'] ?: NULL;
        $innerAnim = $style['ttl_bg']      ?: NULL;
            
        $attributes['class'] .= ' ap-ss-customTitleStyle--' . $user->user_id;

        $customTitle = parent::fnUserTitle($templater, $escape, $user, $withBanner, $attributes);
        
        if(!empty($sparkle))
        {
            $customTitle = "<span class=\"ap-sparkle-{$sparkle}\">{$customTitle}</span>";
        }

        if(isset($innerAnim) && $innerAnim !== NULL)
        {
            $attributes['style'] = 'background-image:url('.htmlspecialchars($innerAnim).')';
            $styleAttr = $this->processAttributeToRaw($attributes, 'style', ' %s', true);

            return "<span id=\"ap-text-bg\" style=\"{$styleAttr}\">{$customTitle}</span>";
        }

        return $customTitle;
    }

    public function fnAvatar($templater, &$escape, $user, $size, $canonical = false, 
    $attributes = [])
    {
        $attributes['class'] = $attributes['class'] ?? NULL;

        if(XF::options()->ap_ss_avatar_frame_type === 'square')
        {
            $attributes['class'] .= ' avatar--square';
        }

        if(!$user instanceof User || !XF::visitor()->canViewAvatarFrame($user))
        {
            return parent::fnAvatar($templater, $escape, $user, $size, $canonical, $attributes);
        }

        $group       = $user->display_style_group_id;
        $groupStyles = $this->groupStyles[$group];
        $groupFrame  = $groupStyles['ap_frame'] ?? NULL;
        $userFrame   = $user->ap_frame          ?? NULL;

        $attributes['class'] .= ' ap-ss-avatarFrame';
                    
        if(!empty($groupFrame) && empty($userFrame))
        {
            $attributes['class'] .= ' ap-ss-avatarFrame--' . $groupFrame;
        }
        elseif(!empty($userFrame))
        {
            $attributes['class'] .= ' ap-ss-avatarFrame--' . $userFrame;
        }
            
        $attributes['class'] = $this->processAttributeToRaw($attributes, 'class', ' %s', true);
        
        return parent::fnAvatar($templater, $escape, $user, $size, $canonical, $attributes);
    }
}
